@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 
 #include <algorithm>
 #include <cctype>
+#include <climits>
 #include <string>
 #include <vector>
 
@@ -27,11 +28,11 @@
 namespace {
 
 void insert_lines( std::vector< std::string > & data,
-                   const int line, const int lines )
+                   const long line, const long lines )
   {
   if( lines > 0 )
     {
-    int i = data.size();
+    long i = data.size();
     data.resize( i + lines );
     while( --i >= line ) data[i+lines].swap( data[i] );
     }
@@ -39,13 +40,13 @@ void insert_lines( std::vector< std::string > & data,
 
 
 void delete_lines( std::vector< std::string > & data,
-                   const int line, const int lines )
+                   const long line, const long lines )
   {
-  if( lines > 0 && line < (int)data.size() )
+  if( lines > 0 && line < (long)data.size() )
     {
-    for( unsigned i = line + lines; i < data.size(); ++i )
+    for( unsigned long i = line + lines; i < data.size(); ++i )
       data[i-lines].swap( data[i] );
-    const int len = std::min( lines, (int)data.size() - line );
+    const long len = std::min( lines, (long)data.size() - line );
     data.erase( data.end() - len, data.end() );
     }
   }
@@ -53,15 +54,17 @@ void delete_lines( std::vector< std::string > & data,
 } // end namespace
 
 
-void Basic_buffer::add_line( const char * const buf, const int len )
+bool Basic_buffer::add_line( const char * const buf, const int len )
   {
   data.back().append( buf, len );
+  if( data.back().size() > LONG_MAX / 2 ) return false;
   if( data.back().size() && data.back()[data.back().size()-1] == '\n' )
     {
     if( data.size() >= data.capacity() && data.size() >= 10000 )
       data.reserve( data.size() + ( data.size() / 10 ) );
     data.push_back( std::string() );
     }
+  return true;
   }
 
 
@@ -69,13 +72,13 @@ void Basic_buffer::add_line( const char * const buf, const int len )
 bool Basic_buffer::detect_and_remove_cr()
   {
   if( lines() <= 1 ) return false;			// empty buffer
-  for( int i = 0; i < last_line(); ++i )
+  for( long i = 0; i < last_line(); ++i )
     {
     const std::string & s = data[i];
-    const int size = s.size();
+    const long size = s.size();
     if( size < 2 || s[size-2] != '\r' ) return false;
     }
-  for( int i = 0; i < last_line(); ++i )	// remove the CR before each LF
+  for( long i = 0; i < last_line(); ++i )	// remove the CR before each LF
     data[i].erase( data[i].size() - 2, 1 );
   return true;
   }
@@ -90,14 +93,14 @@ Basic_buffer::Basic_buffer( const Basic_buffer & b,
   }
 
 
-bool Basic_buffer::blank( const int line ) const
+bool Basic_buffer::blank( const long line ) const
   {
   Point p( line, 0 );
   return ( !pisvalid( p ) || bot( p ) == eol( p ) );
   }
 
 
-int Basic_buffer::characters( const int line ) const
+long Basic_buffer::characters( const long line ) const
   {
   if( line < 0 || line >= lines() ) return 0;
   return data[line].size();
@@ -154,7 +157,7 @@ bool Basic_buffer::pnext( Point & p ) const
 
 bool Basic_buffer::pprev( Point & p ) const
   {
-  int c = characters( p.line );
+  long c = characters( p.line );
   if( p.col > c ) p.col = c;
   if( --p.col >= 0 ) return true;
   c = characters( --p.line ) - 1;
@@ -163,7 +166,7 @@ bool Basic_buffer::pprev( Point & p ) const
   }
 
 
-bool Basic_buffer::pseek( Point & p, const int n ) const
+bool Basic_buffer::pseek( Point & p, const long n ) const
   {
   Point saved_p = p;
   p.col += n;
@@ -171,7 +174,7 @@ bool Basic_buffer::pseek( Point & p, const int n ) const
     {
     while( p.line < last_line() )
       {
-      const int c = characters( p.line );
+      const long c = characters( p.line );
       if( p.col < c || p == eof() ) break;
       p.col -= c; ++p.line;
       }
@@ -192,7 +195,7 @@ bool Basic_buffer::pvalid( Point & p ) const
   if( p < bof() ) p = bof();
   else if( p > eof() ) p = eof();
   else if( p.col < 0 ) p.col = 0;
-  else if( p.col > 0 && p.col >= (int)data[p.line].size() && p != eof() )
+  else if( p.col > 0 && p.col >= (long)data[p.line].size() && p != eof() )
     p.col = data[p.line].size() - 1;
   else return true;
   return false;
@@ -205,7 +208,7 @@ bool Basic_buffer::pputb( Point & p, const Basic_buffer & b,
   {
   if( !pisvalid( p ) || p1 >= p2 || !b.pisvalid( p1 ) || !b.pisvalid( p2 ) )
     return false;
-  const int lines = p2.line - p1.line;
+  const long lines = p2.line - p1.line;
   if( lines == 0 )
     {
     data[p.line].insert( p.col, b.data[p1.line], p1.col, p2.col - p1.col );
@@ -218,7 +221,7 @@ bool Basic_buffer::pputb( Point & p, const Basic_buffer & b,
     data[p.line+lines].append( data[p.line], p.col, data[p.line].size() - p.col );
     data[p.line].erase( p.col, data[p.line].size() - p.col );
     data[p.line].append( b.data[p1.line], p1.col, b.data[p1.line].size() - p1.col );
-    for( int i = 1; i < lines; ++i )
+    for( long i = 1; i < lines; ++i )
       data[p.line+i].assign( b.data[p1.line+i] );
     p.line += lines; p.col = p2.col;
     }
@@ -261,7 +264,7 @@ bool Basic_buffer::pchgc( Point & p, const unsigned char ch )
 bool Basic_buffer::pdelb( const Point & p1, const Point & p2 )
   {
   if( p1 >= p2 || !pisvalid( p1 ) || !pisvalid( p2 ) ) return false;
-  const int lines = p2.line - p1.line;
+  const long lines = p2.line - p1.line;
   if( lines == 0 ) data[p1.line].erase( p1.col, p2.col - p1.col );
   else
     {
@@ -367,7 +370,7 @@ Point Basic_buffer::bot( const Point & p ) const
   {
   Point p1 = bol( p );
   const std::string & s = data[p1.line];
-  while( p1.col < (int)s.size() && ISO_8859::isblank( s[p1.col] ) ) ++p1.col;
+  while( p1.col < (long)s.size() && ISO_8859::isblank( s[p1.col] ) ) ++p1.col;
   return p1;
   }
 
@@ -403,7 +406,7 @@ Point Basic_buffer::eop( const Point & p ) const
 /* Move 'p' to the matching delimiter.
    If (force && forward), fail if [p] is closing delimiter.
    If (force && !forward), fail if [p] is opening delimiter.
-   Returns +1 if done, 0 if [p] is not a delimiter, -1 if no matching delimiter.
+   Return 1 if done, 0 if [p] is not a delimiter, -1 if no matching delimiter.
 */
 int Basic_buffer::set_to_matching_delimiter( Point & p, bool forward,
                                              const bool force ) const
@@ -440,9 +443,9 @@ int Basic_buffer::set_to_matching_delimiter( Point & p, bool forward,
       {
       if( forward )
         { if( pngetc( p1 ) >= 0 && find_text( p1, "*/" ) )
-          { pseek( p1, -2 ); p = p1; return +1; } }
+          { pseek( p1, -2 ); p = p1; return 1; } }
       else
-        { p1 = p; if( rfind_text( p1, "/*" ) ) { p = p1; return +1; } }
+        { p1 = p; if( rfind_text( p1, "/*" ) ) { p = p1; return 1; } }
       return -1;
       }
     return 0;
@@ -460,7 +463,7 @@ int Basic_buffer::set_to_matching_delimiter( Point & p, bool forward,
       const int ch = pngetc( p1 ); if( ch < 0 ) break;
       if( !quote )
         {
-        if( ch == ch2 ) { if( --level < 0 ) { p = p1; return +1; } }
+        if( ch == ch2 ) { if( --level < 0 ) { p = p1; return 1; } }
         else if( ch == ch1 ) { ++level; continue; }
         else if( ch == '\'' )		// ignore single-quoted characters
           {
@@ -487,7 +490,7 @@ int Basic_buffer::set_to_matching_delimiter( Point & p, bool forward,
       if( !quote )
         {
         if( pisescaped( p1 ) ) { ppgetc( p1 ); continue; }
-        if( ch == ch2 ) { if( --level < 0 ) { p = p1; return +1; } }
+        if( ch == ch2 ) { if( --level < 0 ) { p = p1; return 1; } }
         else if( ch == ch1 ) { ++level; continue; }
         else if( ch == '\'' )		// ignore single-quoted characters
           {
@@ -517,7 +520,8 @@ int Basic_buffer::set_to_matching_delimiter( Point & p, bool forward,
 /* Search forward from 'p' for 'pattern' (Boyer-Moore algorithm)
    If found, set 'p' after the substring found
 */
-bool Basic_buffer::find_text( Point & p, const std::string & text, const bool icase ) const
+bool Basic_buffer::find_text( Point & p, const std::string & text,
+                              const bool icase ) const
   {
   if( text.empty() ) return true;
   Point p1 = p;
@@ -527,19 +531,19 @@ bool Basic_buffer::find_text( Point & p, const std::string & text, const bool ic
 
   if( icase )
     {
-    for( unsigned i = 0; i < text.size(); ++i )
+    for( unsigned long i = 0; i < text.size(); ++i )
       itext += ISO_8859::tolower( text[i] );
     textp = &itext;
     }
 
-  std::vector< int > table( 256, textp->size() );
-  for( unsigned i = 0; i < textp->size() - 1; ++i )
+  std::vector< long > table( 256, textp->size() );
+  for( unsigned long i = 0; i < textp->size() - 1; ++i )
     { unsigned char ch = (*textp)[i]; table[ch] = textp->size() - i - 1; }
 
   while( true )
     {
     Point p2 = p1;
-    int i, delta = 0;
+    long i, delta = 0;
     for( i = textp->size() - 1; i >= 0; --i )
       {
       unsigned char ch = (*textp)[i];
@@ -567,19 +571,19 @@ bool Basic_buffer::rfind_text( Point & p, const std::string & text, const bool i
 
   if( icase )
     {
-    for( unsigned i = 0; i < text.size(); ++i )
+    for( unsigned long i = 0; i < text.size(); ++i )
       itext += ISO_8859::tolower( text[i] );
     textp = &itext;
     }
 
-  std::vector< int > table( 256, textp->size() );
-  for( unsigned i = textp->size() - 1; i > 0; --i )
+  std::vector< long > table( 256, textp->size() );
+  for( unsigned long i = textp->size() - 1; i > 0; --i )
     { unsigned char ch = (*textp)[i]; table[ch] = i; }
 
   while( true )
     {
     Point p2 = p1;
-    unsigned i; int delta = 0;
+    unsigned long i; long delta = 0;
     for( i = 0; i < textp->size(); ++i )
       {
       unsigned char ch = (*textp)[i];
@@ -601,10 +605,10 @@ Point Basic_buffer::to_cursor( const Point & pointer ) const
   if( p.line >= 0 && p.line < lines() )
     {
     const std::string & s = data[p.line];
-    const int limit = std::min( pointer.col, (int)s.size() );
+    const long limit = std::min( pointer.col, (long)s.size() );
     while( p.col < limit )
       {
-      int i = p.col;
+      long i = p.col;
       while( i < limit && s[i] != '\t' ) ++i;
       cursor.col += i - p.col;
       if( i < limit ) cursor.col += 8 - ( cursor.col % 8 );
@@ -622,12 +626,12 @@ Point Basic_buffer::to_pointer( const Point & cursor, Point & pcursor ) const
   if( pointer.line >= 0 && pointer.line < lines() )
     {
     const std::string & s = data[pointer.line];
-    const int peolcol = eol( pointer ).col;
+    const long peolcol = eol( pointer ).col;
     while( pcursor.col < cursor.col && pointer.col < peolcol )
       {
       if( s[pointer.col] == '\t' )
         {
-        int col = pcursor.col + 8 - ( pcursor.col % 8 );
+        long col = pcursor.col + 8 - ( pcursor.col % 8 );
         if( col <= cursor.col ) pcursor.col = col; else break;
         }
       else ++pcursor.col;
@@ -638,8 +642,8 @@ Point Basic_buffer::to_pointer( const Point & cursor, Point & pcursor ) const
   }
 
 
-int Basic_buffer::to_string( const Point & p1, const Point & p2,
-                             std::string & text ) const
+long Basic_buffer::to_string( const Point & p1, const Point & p2,
+                              std::string & text ) const
   {
   text.clear();
   if( p1 < p2 && pisvalid( p1 ) && pisvalid( p2 ) )
@@ -648,7 +652,7 @@ int Basic_buffer::to_string( const Point & p1, const Point & p2,
       text.assign( data[p1.line], p1.col, p2.col - p1.col );
     else
       {
-      int line = p1.line;
+      long line = p1.line;
       text.assign( data[line], p1.col, data[line].size() - p1.col );
       while( ++line < p2.line ) text += data[line];
       if( p2.col ) text.append( data[line], 0, p2.col );
@@ -658,20 +662,20 @@ int Basic_buffer::to_string( const Point & p1, const Point & p2,
   }
 
 
-int Basic_buffer::to_string( const Point & p1, const int size,
-                             std::string & text ) const
+long Basic_buffer::to_string( const Point & p1, const long size,
+                              std::string & text ) const
   {
   text.clear();
   if( pisvalid( p1 ) && size > 0 )
     {
-    int rest = size;
-    int line = p1.line;
-    const int sz = std::min( rest, (int)data[line].size() - p1.col );
+    long rest = size;
+    long line = p1.line;
+    const long sz = std::min( rest, (long)data[line].size() - p1.col );
     text.assign( data[line], p1.col, sz );
     rest -= sz;
     while( rest > 0 && ++line < lines() )
       {
-      const int sz = std::min( rest, (int)data[line].size() );
+      const long sz = std::min( rest, (long)data[line].size() );
       text.append( data[line], 0, sz );
       rest -= sz;
       }
