@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -181,21 +181,21 @@ bool Block::copy_block( Buffer & buffer, const Point & p, const bool move )
     {
     Basic_buffer tmp;
     Point p0 = tmp.bof();
-    const int len = end_.col - begin_.col;
-    for( int line = begin_.line; line <= end_.line; ++line )
+    const long len = end_.col - begin_.col;
+    for( long line = begin_.line; line <= end_.line; ++line )
       {
       Point p1( line, begin_.col ), p2( line, end_.col );
       bufferp_->pvalid( p1 ); bufferp_->pvalid( p2 );
       tmp.pputb( p0, *bufferp_, p1, p2 );
-      for( int i = tmp.characters( p0.line ); i < len; ++i )
+      for( long i = tmp.characters( p0.line ); i < len; ++i )
         tmp.pputc( p0, ' ' );
       tmp.pputc( p0, '\n' );
       }
     if( move ) { delete_block(); if( same ) buffer.force_append(); }
-    for( int line = 0; line <= tmp.last_line(); ++line )
+    for( long line = 0; line <= tmp.last_line(); ++line )
       {
       p0 = p; p0.line += line;
-      for( int i = buffer.lines(); i <= p0.line; ++i )
+      for( long i = buffer.lines(); i <= p0.line; ++i )
         {
         Point dummy = buffer.eof();
         const bool ai = buffer.options.auto_indent;
@@ -204,7 +204,7 @@ bool Block::copy_block( Buffer & buffer, const Point & p, const bool move )
         buffer.options.auto_indent = ai;
         }
       if( line >= tmp.last_line() ) break;
-      for( int i = buffer.eol( p0 ).col; i < p0.col; ++i )
+      for( long i = buffer.eol( p0 ).col; i < p0.col; ++i )
         { Point dummy = buffer.eol( p0 );
           buffer.pputc( dummy, ' ' ); buffer.force_append(); }
       Point p1( line, 0 ), p2 = tmp.eol( p1 );
@@ -232,7 +232,7 @@ bool Block::delete_block()
       done = bp->pdelb( begin_, end_ );
     else
       {
-      for( int line = end_.line; line >= begin_.line; --line )
+      for( long line = end_.line; line >= begin_.line; --line )
         {
         Point p1( line, begin_.col ), p2( line, end_.col );
         bp->pvalid( p1 ); bp->pvalid( p2 );
