@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@
 
 namespace {
 
-std::vector< Point * > & get_marks_and_pointers( Buffer & b )
+const std::vector< Point * > & get_marks_and_pointers( Buffer & b )
   {
   static std::vector< Point * > v;
   v.clear();
@@ -56,27 +56,32 @@ std::vector< Point * > & get_marks_and_pointers( Buffer & b )
   }
 
 
+void adjust_point( const Buffer & b, Point & p, const Point & p1,
+                   const Point & p2_old, const Point & p2_new )
+  {
+  if( p <= p1 ) return;			// was before the block, ignore it
+  if( p < p2_old )			// was in the block, keep in
+    {
+    if( p >= p2_new ) { p = p2_new; if( p > p1 ) b.pprev( p ); }
+    else if( !b.pisvalid( p ) ) b.pvalid( p );
+    }
+  else					// was beyond the block
+    {
+    if( p.line == p2_old.line ) p.col += p2_new.col - p2_old.col;
+    p.line += p2_new.line - p2_old.line;
+    }
+  }
+
+
 // adjust marks and pointers after a block insert/delete/replace
 void adjust_marks_and_pointers( Buffer & b, const Point & p1,
                                 const Point & p2_old, const Point & p2_new,
                                 const Point * const p_ignore = 0 )
   {
-  std::vector< Point * > & pv = get_marks_and_pointers( b );
+  const std::vector< Point * > & pv = get_marks_and_pointers( b );
   for( unsigned i = 0; i < pv.size(); ++i )
     if( *pv[i] > p1 && pv[i] != p_ignore )
-      {
-      if( *pv[i] < p2_old )			// was in the block, keep in
-        {
-        if( *pv[i] >= p2_new )
-          { *pv[i] = p2_new; if( *pv[i] > p1 ) b.pprev( *pv[i] ); }
-        else if( !b.pisvalid( *pv[i] ) ) b.pvalid( *pv[i] );
-        }
-      else					// was beyond the block
-        {
-        if( pv[i]->line == p2_old.line ) pv[i]->col += p2_new.col - p2_old.col;
-        pv[i]->line += p2_new.line - p2_old.line;
-        }
-      }
+      adjust_point( b, *pv[i], p1, p2_old, p2_new );
   }
 
 } // end namespace
@@ -144,7 +149,7 @@ void Buffer::Change_history::add_record( const Basic_buffer & buffer,
   {
   if( index + 1 < records() )
     {
-    for( int i = records(); i > index + 1; )
+    for( long i = records(); i > index + 1; )
       record_vector[--i].delete_atoms();
     record_vector.erase( record_vector.begin() + index + 1, record_vector.end() );
     appendable = false;
@@ -196,12 +201,15 @@ Buffer::Buffer( const std::string * const namep, const bool read_only )
 
   if( !f )
     { if( errno == ENOENT ) return; else throw Error( "Error opening file" ); }
+  if( isatty( fileno( f ) ) )
+    { std::fclose( f ); throw Error( "Is a terminal" ); }
 
   const int bufsize = 65536;
   char buf[bufsize];
   bool aborted = false;
   const bool interactive = Screen::height() > 0;
   bool file_eof = true;
+  bool long_line = false;
   while( file_eof )
     {
     const int size = std::fread( buf, 1, bufsize, f );
@@ -211,7 +219,8 @@ Buffer::Buffer( const std::string * const namep, const bool read_only )
       {
       int newpos = pos;
       while( buf[newpos] != '\n' && newpos + 1 < size ) ++newpos;
-      try { add_line( &buf[pos], newpos - pos + 1 ); }
+      try { if( !add_line( &buf[pos], newpos - pos + 1 ) )
+              { file_eof = false; long_line = true; } }
       catch( ... ) { file_eof = false; break; }
       pos = newpos + 1;
       }
@@ -219,20 +228,21 @@ Buffer::Buffer( const std::string * const namep, const bool read_only )
       { file_eof = false; aborted = true; }
     }
 
-  const bool file_error = std::ferror( f );
+  bool file_error = std::ferror( f );
   if( file_eof ) file_eof = std::feof( f );
-  if( f != stdin ) std::fclose( f );
+  if( f != stdin ) { if( std::fclose( f ) != 0 ) file_error = true; }
   else if( !ttyname( 1 ) || !std::freopen( ttyname( 1 ), "r", stdin ) )
     throw Error( "Error opening terminal for input" );
   if( aborted ) throw Error( "Aborted" );
   if( file_error ) throw Error( "Error reading file" );
+  if( long_line ) throw Error( "Line too long" );
   if( !file_eof ) throw Error( "Not enough memory" );
   crlf = detect_and_remove_cr();
   set_marks();
   }
 
 
-int Buffer::set_marks()
+int Buffer::set_marks()		// returns the number of new marks set
   {
   int c = 0;
   if( mark[0].line < 0 )
@@ -247,7 +257,7 @@ int Buffer::set_marks()
     }
   for( long i = 1; i < 10; ++i )
     {
-    const int line =
+    const long line =
       ( lines() <= 1000 ) ? 100 * i - 1 : ( lines() * i + 9 ) / 10 - 1;
     if( line >= lines() ) break;
     if( mark[i].line >= 0 )
@@ -262,8 +272,8 @@ int Buffer::set_marks()
 /* *namep  name   save_to   action
      ""     ""       x      error              (no names)
      ""      x     true     error              (no name to save to)
-     x     valid   false    save               (if !read_only)
-   valid    ""     false    save_and_set_name  (if !read_only)
+     x     valid   false    save               (if name != *namep, save to)
+   valid    ""     false    save_and_set_name  (if read_only, save to)
    valid     x     true     save_to            (save to 'other' file)
 */
 bool Buffer::save( const std::string * namep, bool save_to,
@@ -274,7 +284,9 @@ bool Buffer::save( const std::string * namep, bool save_to,
   if( !valid_namep && !had_name ) return false;		// no names
   if( !valid_namep && save_to ) return false;		// no name to save to
 
-  if( !save_to && had_name && valid_namep && name_ != *namep ) save_to = true;
+  if( !save_to && valid_namep &&
+      ( ( had_name && name_ != *namep ) || ( !had_name && options.read_only ) ) )
+    save_to = true;
   if( !save_to && options.read_only ) return false;
 
   int mode = 0;
@@ -336,7 +348,7 @@ bool Buffer::save( const std::string * namep, bool save_to,
     { if( !had_name ) { name_.clear(); } throw Error( "Error closing file" ); }
   if( !save_to )
     {
-    for( int i = change_history.records() - 1; i >= 0; --i )
+    for( long i = change_history.records() - 1; i >= 0; --i )
       if( change_history.record_vector[i].modified == false )
         { change_history.record_vector[i].modified = true; break; }
     reset_appendable();
@@ -350,10 +362,10 @@ long Buffer::character_offset( const Point & p, int & percent ) const
   {
   long total = 0;
 
-  for( int i = 0; i < p.line; ++i ) total += characters( i );
+  for( long i = 0; i < p.line; ++i ) total += characters( i );
   long offset = total + p.col;
   if( crlf ) { offset += p.line; if( (*this)[p] == '\n' ) ++offset; }
-  for( int i = p.line; i < last_line(); ++i ) total += characters( i );
+  for( long i = p.line; i < last_line(); ++i ) total += characters( i );
   if( crlf ) total += last_line();
   total += eof().col;
   if( total > 0 ) percent = ( 100LL * offset ) / total;
@@ -409,7 +421,7 @@ bool Buffer::pputc( Point & p, const unsigned char ch )
     {
     if( options.overwrite && p < eol( p ) )
       {
-      const Point p1 = Point( p.line, p.col + 1 );
+      const Point p1( p.line, p.col + 1 );
       Change_history::Record r( p, p1, modified_ );
       Change_history::Atom a( p, p1, *this );
       Basic_buffer::pchgc( p, ch );
@@ -423,7 +435,7 @@ bool Buffer::pputc( Point & p, const unsigned char ch )
       Change_history::Record r( p0, p, modified_ );
       r.add_atom( Change_history::Atom( p0, p ) );
       change_history.add_record( *this, r );
-      std::vector< Point * > & pv = get_marks_and_pointers( *this );
+      const std::vector< Point * > & pv = get_marks_and_pointers( *this );
       for( unsigned i = 0; i < pv.size(); ++i )
         if( pv[i]->line == p0.line && pv[i]->col > p0.col && pv[i] != &p )
           ++pv[i]->col;
@@ -437,13 +449,17 @@ bool Buffer::pputc( Point & p, const unsigned char ch )
         while( p1 > pt && pprev( p1 ) && ISO_8859::isblank( (*this)[p1] ) );
         if( p1 >= pt && p1 < p2 && pnext( p1 ) && pnext( p2 ) )
           {
-          reset_appendable(); pdelb( p1, p2 ); p2 = p1;
-          force_append(); pputc( p2, '\n' );
+          Point p3 = p1;
+          reset_appendable(); pdelb( p1, p2 );
+          force_append(); pputc( p3, '\n' );
           if( !options.auto_indent && options.lmargin() > 0 )
             {
             for( int i = 0; i < options.lmargin(); ++i ) tmp.pputc( dummy, ' ' );
-            force_append(); pputb( p2, tmp, tmp.bof(), tmp.eof(), true );
+            force_append(); pputb( p3, tmp, tmp.bof(), tmp.eof(), true );
             }
+          for( unsigned i = 0; i < pv.size(); ++i )	// adjust p not in pv
+            { if( pv[i] == &p ) break;
+              if( i + 1 == pv.size() ) adjust_point( *this, p, p1, p2, p3 ); }
           }
         }
       }
@@ -514,6 +530,7 @@ bool Buffer::replace( const Point & p1, Point & p2, const Basic_buffer & b,
 bool Buffer::undo( Point & p )
   {
   if( change_history.index < 0 ) return false;
+  Screen::show_feedback( "undoing..." );
   Change_history::Record & rec = change_history.record_vector[change_history.index];
   for( unsigned i = rec.atom_vector.size(); i > 0; )
     {
@@ -544,6 +561,7 @@ bool Buffer::undo( Point & p )
 bool Buffer::redo( Point & p )
   {
   if( change_history.index + 1 >= change_history.records() ) return false;
+  Screen::show_feedback( "redoing..." );
   ++change_history.index;
   Change_history::Record & rec = change_history.record_vector[change_history.index];
   for( unsigned i = 0; i < rec.atom_vector.size(); ++i )
@@ -569,3 +587,66 @@ bool Buffer::redo( Point & p )
   std::swap( modified_, rec.modified );
   return true;
   }
+
+
+// reformat paragraph around cursor and move cursor to ( bop.line, lmargin )
+bool Buffer::reformat_paragraph( Point & cursor, const bool append_change )
+  {
+  const Point bop = Basic_buffer::bop( cursor );	// begin of paragraph
+  const Point eop = Basic_buffer::eop( cursor );	// end of paragraph
+  if( bop >= eop ) return false;
+  const Point bot = Basic_buffer::bot( bop );	// begin of text in paragraph
+  const int rmargin = options.rmargin();
+  const int lmargin = std::max( options.lmargin(),
+                                (int)std::min( rmargin - 1L, cursor.col ) );
+  Buffer tmp;
+  tmp.options.set_rmargin( rmargin );
+  tmp.options.word_wrap = true;
+  Point dummy = tmp.bof();
+  if( bop < bot && to_cursor( bot ).col > lmargin )
+    tmp.Basic_buffer::pputb( dummy, *this, bop, bot );
+  tmp.options.set_lmargin( lmargin );
+  bool period2 = false;		// prev char was period in 2 spaces mode
+  bool pending_space = false;
+  bool change = false;
+  for( Point p = bot; p < eop; )
+    {
+    unsigned char ch = pgetc( p );
+    if( std::isspace( ch ) )		// 'std' to exclude no-break space
+      {
+      if( ( ch != ' ' && ch != '\n' ) ) change = true;
+      pending_space = true;
+      }
+    else
+      {
+      if( pending_space )
+        { pending_space = false; tmp.pputc( dummy, ' ' );
+          if( period2 ) tmp.pputc( dummy, ' ' ); }
+      tmp.pputc( dummy, ch ); // if( dummy != tmp.eof() ) std::exit( 3 );
+      period2 = ( ch == '.' && options.two_spaces );
+      }
+    if( Screen::kbhit() >= 0 && Screen::wait_kbhit() == 3 )
+      throw Error( "Aborted" );
+    }
+  if( dummy != tmp.bol( dummy ) ) tmp.pputc( dummy, '\n' );
+  if( !change ) change = ( tmp.last_line() != ( eop.line - bop.line ) );
+  if( !change )
+    for( long line = 0; line < tmp.lines(); ++line )
+      if( tmp.characters( line ) != characters( bop.line + line ) &&
+          ( !tmp.blank( line ) || !blank( bop.line + line ) ) )
+        { change = true; break; }
+  // detect changes that do not change total number of spaces in line
+  if( !change && options.two_spaces )
+    for( long line = 0; line < tmp.lines(); ++line )
+      if( tmp.get_line( line ) != get_line( bop.line + line ) &&
+          ( !tmp.blank( line ) || !blank( bop.line + line ) ) )
+        { change = true; break; }
+  if( change )
+    {
+    if( append_change ) force_append(); else reset_appendable();
+    Point p = eop;
+    replace( bop, p, tmp, tmp.bof(), tmp.eof() );
+    cursor.line = bop.line; cursor.col = lmargin;
+    }
+  return change;
+  }
