@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -23,9 +23,10 @@
 */
 struct Point
   {
-  int line, col;
+  long line, col;
 
-  explicit Point( int l = -1, int c = 0 ) : line( l ), col( c ) {}
+  explicit Point( long l = -1, long c = 0 ) : line( l ), col( c ) {}
+  Point & assign( long l, long c ) { line = l; col = c; return *this; }
 
   Point & operator+=( const Point & p )
     { line += p.line; col += p.col; return *this; }
@@ -65,7 +66,7 @@ class Basic_buffer
   void operator=( const Basic_buffer & );	// declared as private
 
 protected:
-  void add_line( const char * const buf, const int len );
+  bool add_line( const char * const buf, const int len );
   bool detect_and_remove_cr();
 
 public:
@@ -73,23 +74,23 @@ public:
   Basic_buffer( const Basic_buffer & b, const Point & p1, const Point & p2 );
 
   // true if line is blank (invalid, empty, or containing only whitespace)
-  bool blank( const int line ) const;
-  int  characters( const int line ) const;
-  bool compare_lines( const int line1, const int line2 ) const
+  bool blank( const long line ) const;
+  long characters( const long line ) const;
+  bool compare_lines( const long line1, const long line2 ) const
     { return ( data[line1] == data[line2] ); }
   bool empty() const { return ( data.size() == 1 && data[0].empty() ); }
-  int  lines() const { return data.size(); }
-  int  last_line() const { return lines() - 1; }
+  long lines() const { return data.size(); }
+  long last_line() const { return lines() - 1; }
   bool one_character() const;		// buffer has only one character
 
-  const std::string & get_line( const int line ) const { return data[line]; }
+  const std::string & get_line( const long line ) const { return data[line]; }
   int  operator[]( const Point & p ) const;
   int  pgetc( Point & p ) const;	// get and move next
   int  pngetc( Point & p ) const;	// move next and get
   int  ppgetc( Point & p ) const;	// move prev and get
   bool pnext( Point & p ) const;
   bool pprev( Point & p ) const;
-  bool pseek( Point & p, const int n ) const;
+  bool pseek( Point & p, const long n ) const;
   bool pvalid( Point & p ) const;	// make p valid, return old p status
 
        // insert block b.[p1,p2) at p and move next
@@ -129,8 +130,8 @@ public:
 
   Point to_cursor( const Point & pointer ) const;
   Point to_pointer( const Point & cursor, Point & pcursor ) const;
-  int to_string( const Point & p1, const Point & p2, std::string & text ) const;
-  int to_string( const Point & p1, const int size, std::string & text ) const;
+  long to_string( const Point & p1, const Point & p2, std::string & text ) const;
+  long to_string( const Point & p1, const long size, std::string & text ) const;
   };
 
 
@@ -148,11 +149,11 @@ class Buffer : public Basic_buffer
       Point end;		// Buffer position of end of insert
       Basic_buffer * bbp;	// Basic_buffer containing deleted data
 
-      // Creates an insert Atom ([p1,p2) -> inserted_text)
+      // Create an insert Atom ([p1,p2) -> inserted_text)
       Atom( const Point & p1, const Point & p2 )
         : begin( p1 ), end( p2 ), bbp( 0 ) {}
 
-      // Creates a delete Atom (bbp -> deleted_text)
+      // Create a delete Atom (bbp -> deleted_text)
       Atom( const Point & p1, const Point & p2, const Basic_buffer & b )
         : begin( p1 ), end( p1 ), bbp( 0 )
         { if( p1 < p2 ) bbp = new Basic_buffer( b, p1, p2 ); }
@@ -173,7 +174,7 @@ class Buffer : public Basic_buffer
       void delete_atoms();
       };
 
-    int index;			// Index of record to be undone
+    long index;			// Index of record to be undone
     mutable bool appendable;	// True if last record added is appendable
     mutable bool force_append;
     std::vector< Record > record_vector;
@@ -183,7 +184,7 @@ class Buffer : public Basic_buffer
     ~Change_history();
 
     void add_record( const Basic_buffer & buffer, Record & r );
-    int records() const { return record_vector.size(); }
+    long records() const { return record_vector.size(); }
     };
 
   Change_history change_history;
@@ -254,4 +255,6 @@ public:
   void force_append() const { change_history.force_append = true; }
   void reset_appendable() const
     { change_history.appendable = change_history.force_append = false; }
+
+  bool reformat_paragraph( Point & cursor, const bool append_change );
   };
