@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ int last_visited_;			// absolute index for last_visited
 std::vector< Buffer_handle > data;
 
 
-// Saves modified non-empty buffers if editor dies
+// Save modified non-empty buffers if editor dies
 //
 void emergency_save()
   {
@@ -164,8 +164,7 @@ void Bufhandle_vector::set_first( const int ai )
 
 
 int Bufhandle_vector::find_or_add_handle( const std::string * const namep,
-                                          int i, const int line, const int col,
-                                          const bool read_only )
+              int i, const long line, const long col, const bool read_only )
   {
   if( namep && namep->size() )
     for( int j = 0; j < handles(); ++j )
@@ -189,8 +188,8 @@ int Bufhandle_vector::find_or_add_handle( const std::string * const namep,
 
 
 // Add empty buffer if no files given or stdin is not a tty
-void Bufhandle_vector::add_handle_if_pending_input_or_empty( const int line,
-                                                             const int col )
+void Bufhandle_vector::add_handle_if_pending_input_or_empty( const long line,
+                                                             const long col )
   {
   if( !handles() || !isatty( fileno( stdin ) ) )
     find_or_add_handle( 0, -1, line, col );
