@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 class Buffer_handle
   {
   Buffer * bufferp_;	// handled buffer
+  bool first_post_;	// set to false first time handle is displayed
 
 public:
   Point top_left;	// buffer coordinates of window top-left corner
@@ -25,12 +26,14 @@ public:
   Point pointer;	// current buffer character (index in buffer[])
   Point pcursor;	// buffer coordinates of current buffer character
 
-  explicit Buffer_handle( Buffer & buf, const int line = 0, const int col = 0 )
-    : bufferp_( &buf ), top_left( 0, 0 ), cursor( line, col )
+  explicit Buffer_handle( Buffer & buf, const long line = 0, const long col = 0 )
+    : bufferp_( &buf ), first_post_( true ),
+      top_left( 0, 0 ), cursor( line, col )
     { pointer = buf.to_pointer( cursor, pcursor ); }
 
   Buffer & buffer() { return *bufferp_; }
   const Buffer & buffer() const { return *bufferp_; }
+  bool first_post() { bool b = first_post_; first_post_ = false; return b; }
   };
 
 
@@ -55,9 +58,9 @@ void prev();
 void set_first( const int ai );
 
 int find_or_add_handle( const std::string * const namep = 0,
-                        int i = -1, const int line = 0, const int col = 0,
+                        int i = -1, const long line = 0, const long col = 0,
                         const bool read_only = false );
-void add_handle_if_pending_input_or_empty( const int line, const int col );
+void add_handle_if_pending_input_or_empty( const long line, const long col );
 void duplicate_handle( int i );
 bool delete_handle( int i );
 void delete_all_handles();
