@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -99,8 +99,9 @@ int base64_value( const unsigned char ch )
   }
 
 
-// Returns -1 if not found, 256 if code should be ignored
-//
+/* Decode UCS to ISO-8859-15.
+   Return -1 if not found, 256 if code should be ignored.
+*/
 int map_to_byte( const int code )
   {
   if( code < 0 ) return -1;
@@ -735,8 +736,12 @@ int map_to_byte( const int code )
     case 0x209B: return 's';	// latin subscript small letter s
     case 0x209C: return 't';	// latin subscript small letter t
     case 0x20AC: return 0xA4;	// euro sign
+    case 0x212A: return 'K';	// Kelvin sign
+    case 0x212B: return 0xC5;	// Angstrom sign
     case 0x2191: return '^';	// upwards arrow
     case 0x2193: return 'V';	// downwards arrow
+    case 0x21D1: return '^';	// upwards double arrow
+    case 0x21D3: return 'V';	// downwards double arrow
     case 0x2211: return 'S';	// N-ary summation
     case 0x2212: return '-';	// minus sign
     case 0x2213: return 0xB1;	// minus-or-plus sign
@@ -776,6 +781,7 @@ int map_to_byte( const int code )
   }
 
 
+// Decode UCS to string of ISO-8859-15 chars. Return 0 if not found.
 const char * map_to_string( const int code )
   {
   switch( code )
@@ -843,10 +849,16 @@ const char * map_to_string( const int code )
     case 0x2048: return "?!";
     case 0x2049: return "!?";
     case 0x2057: return "''''";
+    case 0x2116: return "N";	// numero sign
     case 0x2122: return "TM";	// trade mark sign
     case 0x2190: return "<-";	// leftwards arrow
     case 0x2192: return "->";	// rightwards arrow
     case 0x2194: return "<->";	// left right arrow
+    case 0x21B2: return "<-'";	// downwards arrow with tip leftwards
+    case 0x21B3: return "`->";	// downwards arrow with tip rightwards
+    case 0x21D0: return "<=";	// leftwards double arrow
+    case 0x21D2: return "=>";	// rightwards double arrow
+    case 0x21D4: return "<=>";	// left right double arrow
     case 0x221A: return "\\/";	// square root
     case 0x221E: return "oo";	// infinity
     case 0x2237: return "::";	// proportion
@@ -914,7 +926,7 @@ void Encoding::base64_encode( const std::string & in, std::string & out )
     "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
   out.clear();
-  for( unsigned i = 0; i < in.size(); i += 3 )
+  for( unsigned long i = 0; i < in.size(); i += 3 )
     {
     const bool s1 = ( i + 1 < in.size() );
     const bool s2 = ( i + 2 < in.size() );
@@ -930,17 +942,16 @@ void Encoding::base64_encode( const std::string & in, std::string & out )
 
 
 /* Decode base64 encoded input string 'in' to output string 'out'.
-   Returns true if decoding was successful, i.e. if the input was valid
-   base64 data. Note that as soon as any invalid character is
-   encountered, decoding is stopped, the index of the invalid 4-byte
-   group is stored in *idxp, and false is returned. This means that any
-   line terminators must be removed from the input string before calling
-   this function.
+   Return true if decoding was successful, i.e. if the input was valid
+   base64 data. Note that as soon as any invalid character is found,
+   decoding is stopped, the index of the invalid 4-byte group is stored in
+   *idxp, and false is returned. This means that any line terminators must
+   be removed from the input string before calling this function.
 */
 bool Encoding::base64_decode( const std::string & in, std::string & out,
-                              int * const idxp )
+                              long * const idxp )
   {
-  unsigned i;
+  unsigned long i;
   out.clear();
 
   for( i = 0; i + 3 < in.size(); i += 4 )
@@ -972,15 +983,15 @@ bool Encoding::base64_decode( const std::string & in, std::string & out,
 
 
 /* Decode quoted-printable encoded input string 'in' to output string 'out'.
-   Returns 0 if decoding was successful, i.e. if the input was valid
+   Return 0 if decoding was successful, i.e. if the input was valid
    quoted-printable data. Note that as soon as any invalid character is
-   encountered, decoding is stopped, the index of the invalid character
-   is stored in *idxp, and false is returned.
+   found, decoding is stopped, the index of the invalid character is stored
+   in *idxp, and false is returned.
 */
 bool Encoding::quoted_printable_decode( const std::string & in,
-                                        std::string & out, int * const idxp )
+                                        std::string & out, long * const idxp )
   {
-  unsigned i;
+  unsigned long i;
   out.clear();
 
   for( i = 0; i < in.size(); ++i )
@@ -1078,16 +1089,16 @@ unsigned char Encoding::rot47( const unsigned char ch )
 
 
 /* Encode ISO-8859-15 encoded input string 'in' to output string 'out'.
-   Returns false if no encoding is needed, i.e. if the input is already
+   Return false if no encoding is needed, i.e. if the input is already
    valid ASCII data. Any ASCII text in 'in' is copied unmodified.
 */
 bool Encoding::ascii_encode( const std::string & in, std::string & out )
   {
   bool modified = false;
   out.clear();
-  for( unsigned i = 0; i < in.size(); )
+  for( unsigned long i = 0; i < in.size(); )
     {
-    unsigned j = i;
+    unsigned long j = i;
     while( i < in.size() && (unsigned char)in[i] < 128 ) ++i;
     if( i > j && ( modified || i < in.size() ) ) out.append( in, j, i - j );
     if( i < in.size() )
@@ -1101,7 +1112,7 @@ bool Encoding::ascii_encode( const std::string & in, std::string & out )
 
 
 /* Encode ISO-8859-15 encoded input string 'in' to output string 'out'.
-   Returns false if no encoding is needed, i.e. if the input is already
+   Return false if no encoding is needed, i.e. if the input is already
    valid UTF-8 data.
    If force is true and any character is >= 128, encoding is performed
    unconditionally.
@@ -1109,28 +1120,28 @@ bool Encoding::ascii_encode( const std::string & in, std::string & out )
 bool Encoding::utf8_encode( const std::string & in, std::string & out,
                             const bool force )
   {
-  int len;
   bool modified = false;
   out.clear();
 
-  for( unsigned i = 0; i < in.size(); )
+  for( unsigned long i = 0; i < in.size(); )
     {
     if( (unsigned char)in[i] < 128 ) { ++i; continue; }
+    int len;
     if( force || utf8_to_ucs( in, i, &len ) < 0 ) { modified = true; break; }
     i += len;
     }
   if( modified )
-    for( unsigned i = 0; i < in.size(); ++i )
+    for( unsigned long i = 0; i < in.size(); ++i )
       ucs_to_utf8( map_to_ucs( in[i] ), out );
   return modified;
   }
 
 
 /* 'seq' contains an UTF-8 (possibly) multibyte character sequence.
-   Returns the corresponding code and, in *lenp, the number of bytes read.
-   Returns -1 if error.
+   Return the corresponding code and, in *lenp, the number of bytes read.
+   Return -1 if error.
 */
-int Encoding::utf8_to_ucs( const std::string & seq, const unsigned i,
+int Encoding::utf8_to_ucs( const std::string & seq, const unsigned long i,
                            int * const lenp )
   {
   if( i >= seq.size() ) return -1;
@@ -1160,20 +1171,20 @@ int Encoding::utf8_to_ucs( const std::string & seq, const unsigned i,
 
 
 /* Decode UTF-8 encoded input string 'in' to output string 'out'.
-   Returns 0 if decoding was successful, i.e. if the input was valid
-   UTF-8 data in the ISO-8859-[1|15] range. Note that as soon as any
-   invalid character is encountered, decoding is stopped, the index of
-   the invalid character is stored in *idxp, and:
+   Return 0 if decoding was successful, i.e. if the input was valid UTF-8
+   data in the ISO-8859-[1|15] range. Note that as soon as any invalid
+   character is found, decoding is stopped, the index of the invalid
+   character is stored in *idxp, and:
      if invalid UTF-8 data is found then -1 is returned,
      else the UCS code of the first character out of range is returned.
    If force is true, out of range UTF-8 characters are copied unmodified
    instead of returning an error.
 */
 int Encoding::utf8_decode( const std::string & in, std::string & out,
-                           int * const idxp, const bool force )
+                           long * const idxp, const bool force )
   {
   out.clear();
-  for( unsigned i = 0; i < in.size(); )
+  for( unsigned long i = 0; i < in.size(); )
     {
     int len;
     const int code = utf8_to_ucs( in, i, &len );
@@ -1194,17 +1205,17 @@ int Encoding::utf8_decode( const std::string & in, std::string & out,
 
 /* Copy the UTF-8 encoded input string 'in' to output string 'out',
    removing any out of range UTF-8 characters.
-   Returns 1 if the copy was succesful.
-   Returns 0 if no copy is needed (no out of range UTF-8 characters in 'in').
-   Returns -1 if an invalid UTF-8 character is encountered. The index of
-   the invalid character is stored in *idxp.
+   Return 1 if the copy was succesful.
+   Return 0 if no copy is needed (no out of range UTF-8 characters in 'in').
+   Return -1 if an invalid UTF-8 character is found. The index of the
+   invalid character is stored in *idxp.
 */
 int Encoding::remove_utf8_out_of_range( const std::string & in, std::string & out,
-                                        int * const idxp )
+                                        long * const idxp )
   {
   bool modified = false;
   out.clear();
-  for( unsigned i = 0; i < in.size(); )
+  for( unsigned long i = 0; i < in.size(); )
     {
     int len;
     const int code = utf8_to_ucs( in, i, &len );
