@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -126,10 +126,10 @@ enum Code {
 
 
 /* 'seq[i]' begins a escape sequence (the characters following a '\').
-   Returns the corresponding code and, in *lenp, the number of bytes read.
-   Returns -1 if error.
+   Return the corresponding code and, in *lenp, the number of bytes read.
+   Return -1 if error.
 */
-int ISO_8859::escape( const std::string & seq, const unsigned i, int * lenp )
+int ISO_8859::escape( const std::string & seq, const unsigned long i, int * lenp )
   {
   if( i >= seq.size() ) return -1;
   int len = 1;
@@ -167,7 +167,7 @@ int ISO_8859::escape( const std::string & seq, const unsigned i, int * lenp )
 
 void ISO_8859::escapize( std::string & s )
   {
-  for( unsigned i = 0; i < s.size(); ++i )
+  for( unsigned long i = 0; i < s.size(); ++i )
     {
     if( !ISO_8859::iscntrl( s[i] ) && s[i] != '\\' ) continue;
     s.insert( s.begin() + i, '\\' ); ++i;
@@ -195,7 +195,7 @@ void ISO_8859::escapize( std::string & s )
 
 void ISO_8859::deescapize_search_string( std::string & s )
   {
-  for( unsigned i = 0; i + 1 < s.size(); ++i )
+  for( unsigned long i = 0; i + 1 < s.size(); ++i )
     {
     if( s[i] != '\\' ) continue;
     int len, c = ISO_8859::escape( s, i + 1, &len );
