@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,10 +18,10 @@
 namespace ISO_8859 {
 
 /* 'seq[i]' begins a escape sequence (the characters following a '\').
-   Returns the corresponding code and, in *lenp, the number of bytes read.
-   Returns -1 if error.
+   Return the corresponding code and, in *lenp, the number of bytes read.
+   Return -1 if error.
 */
-int escape( const std::string & seq, const unsigned i, int * lenp = 0 );
+int escape( const std::string & seq, const unsigned long i, int * lenp = 0 );
 
 // Replace special characters with escape sequences; '\n' --> "\n"
 //
