@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,12 +17,12 @@
 /*
    Exit status: 0 for a normal exit, 1 for environmental problems
    (invalid flags, I/O errors, etc), 2 to indicate an invalid or
-   unreadable input file, 3 for an internal consistency error (eg, bug)
+   unreadable input file, 3 for an internal consistency error (e.g., bug)
    which caused moe to panic.
 */
 
 #include <cctype>
-#if defined(__CYGWIN__)
+#if defined __CYGWIN__
 #include <clocale>
 #endif
 #include <csignal>
@@ -43,34 +43,33 @@ namespace {
 
 const char * const     program_name = "moe";
 const char * const config_file_name = "moerc";
-const char * const     program_year = "2021";
+const char * const     program_year = "2022";
 const char * invocation_name = program_name;		// default value
 
 
 void show_help()
   {
-  std::printf( "GNU moe is a powerful, 8-bit clean, console text editor for ISO-8859 and\n"
-               "ASCII character encodings. It has a modeless, user-friendly interface,\n"
-               "online help, multiple windows, unlimited undo/redo capability, unlimited\n"
-               "line length, unlimited buffers, global search/replace (on all buffers at\n"
-               "once), block operations, automatic indentation, word wrapping, file name\n"
-               "completion, directory browser, duplicate removal from prompt histories,\n"
-               "delimiter matching, text conversion from/to UTF-8, romanization, etc.\n"
+  std::printf( "GNU moe is a console text editor for ISO-8859 and ASCII character encodings.\n"
+               "It has a modeless, user-friendly interface, online help, multiple windows,\n"
+               "global search/replace (on all buffers at once), block operations, automatic\n"
+               "indentation, word wrapping, file name completion, directory browser,\n"
+               "duplicate removal from prompt histories, delimiter matching, text conversion\n"
+               "from/to UTF-8, romanization, etc. The file size, line length, number of\n"
+               "buffers, and undo/redo capability are only limited by the amount of memory\n"
+               "available and the size of the address space of your machine.\n"
                "\nMoe respects your work. By default it won't automatically add, change, or\n"
-               "remove not even one byte in your files. Moe is a WYTIWYG (what you type is\n"
-               "what you get) editor.\n"
+               "remove a single byte in your files. Moe is a WYTIWYG (what you type is what\n"
+               "you get) editor.\n"
                "\nMoe can easily edit thousands of files at the same time.\n"
-               "\nMoe uses ISO-8859-15 instead of UTF-8 because an 8-bit character set\n"
-               "(combined with romanization if needed) can convey meaning safely and more\n"
-               "efficiently than UTF-8 can.\n"
-               "\nUsage: %s [global_options] [[+line[,col]] file_name [file_options]]...\n",
+               "\nUsage: %s [global_options] [[+[line[,col]]] file_name [file_options]]...\n",
                invocation_name );
   std::printf( "\n'global_options' are a mix of editor options and default 'file_options'.\n"
                "Most long option names have a negative form '--backup' '--no-backup'.\n"
-               "\nEach file name may be preceded by '+line[,column]' to start the cursor\n"
+               "\nEach file name may be preceded by '+[line[,column]]' to start the cursor\n"
                "at the line, and optionally column, specified. 'line' and 'column' are\n"
                "applied to subsequent files until new values are specified for them.\n"
-               "\n'-' used as a file name argument means standard input.\n"
+               "A '+' alone puts the cursor at end-of-buffer.\n"
+               "\nA hyphen '-' used as a file name argument means standard input.\n"
                "Directories are recursively descended into.\n"
                "\nEditor options:\n"
                "  -h, --help               display this help and exit\n"
@@ -98,7 +97,7 @@ void show_help()
                "  -2, --two-spaces         make reformat put two spaces after period\n"
                "\nExit status: 0 for a normal exit, 1 for environmental problems\n"
                "(invalid flags, I/O errors, etc), 2 to indicate an invalid or\n"
-               "unreadable input file, 3 for an internal consistency error (eg, bug)\n"
+               "unreadable input file, 3 for an internal consistency error (e.g., bug)\n"
                "which caused moe to panic.\n"
                "\nReport bugs to bug-moe@gnu.org\n"
                "Moe home page: http://www.gnu.org/software/moe/moe.html\n"
@@ -224,7 +223,7 @@ void RC::show_error( const char * const msg, const int errcode,
 int main( const int argc, const char * const argv[] )
   {
   if( argc > 0 ) invocation_name = argv[0];
-#if defined(__CYGWIN__)
+#if defined __CYGWIN__
   // set an 8-bit "C" locale in Cygwin so that ncurses can show chars > 127
   std::setlocale( LC_ALL, "C.ISO-8859-15" );
 #endif
