@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -59,7 +59,7 @@ void show( const std::vector< std::string > & name_vector, const int lines,
         if( indicator ) ++i1;		// skip modified or crlf indicator
         s += name_vector[i];
         i2 = s.size();
-        cursor = Point( line, std::min( i2, Screen::width() - 1 ) );
+        cursor.assign( line, std::min( i2, Screen::width() - 1 ) );
         }
       else s += name_vector[i];
       const unsigned col = std::min( Screen::width(), ( ( ( i % columns ) + 1 ) * ( Screen::width() + 2 ) ) / columns );
@@ -135,7 +135,7 @@ void split_filename( const std::string & name,
 } // end namespace Menu
 
 
-// Returns handle index, or -1 if aborted.
+// Return handle index, or -1 if aborted.
 //
 int Menu::bufhandle_menu( int current, const int abort_key )
   {
@@ -221,7 +221,7 @@ int Menu::bufhandle_menu( int current, const int abort_key )
 
 
 /* 'name' contains the file name to be modified (may be empty).
-   Returns false if aborted.
+   Return false if aborted.
 */
 bool Menu::file_menu( const std::string & prompt, std::string & name )
   {
@@ -330,8 +330,8 @@ bool Menu::file_menu( const std::string & prompt, std::string & name )
 
 /* 'name' contains the default result (may be empty), and stores the result
    (if any).
-   Returns the size of the result string, 0 if none, -1 if aborted.
-   'name' is cleared if aborted.
+   Return the size of the result string, 0 if none, -1 if aborted.
+   Clear 'name' if aborted.
 */
 int Menu::get_filename( const std::string & prompt, std::string & name,
                         const int abort_key )
