@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -310,7 +310,7 @@ void show( const Buffer & buffer, Point & cursor )
     for( int i = columns * line; i < columns * ( line + 1 ) && i < entries; ++i )
       {
       if( i == current )
-        { cursor = Point( line, s.size() ); s += "@i"; offset += 2; }
+        { cursor.assign( line, s.size() ); s += "@i"; offset += 2; }
       s += table[i].ch; s += ' '; s += table[i].str;
       if( table[i].status )
         { const char * const st = table[i].status( buffer ); if( st ) s += st; }
