@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 #include <algorithm>
 #include <cctype>
 #include <cerrno>
-#include <climits>
+#include <climits>		// SSIZE_MAX
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
@@ -26,6 +26,7 @@
 #include <string>
 #include <vector>
 #include <dirent.h>
+#include <stdint.h>		// SIZE_MAX
 #include <unistd.h>
 #include <sys/stat.h>
 
@@ -37,6 +38,10 @@
 #include "rc.h"
 #include "regex.h"
 
+#if ( defined  SIZE_MAX &&  SIZE_MAX < ULONG_MAX ) || \
+    ( defined SSIZE_MAX && SSIZE_MAX <  LONG_MAX )
+#error "Environments where 'size_t' is narrower than 'long' are not supported."
+#endif
 
 // order of application of file options by place of specification:
 // 1 options specified in rc file as 'default file options'.
@@ -135,19 +140,6 @@ const Arg_parser::Option options[] =
   { 0,                 0,                Arg_parser::no  } };
 
 
-const char * optname( const int code )
-  {
-  static char buf[2] = "?";
-
-  if( code != 0 )
-    for( int i = 0; options[i].code; ++i )
-      if( code == options[i].code )
-        { if( options[i].name ) return options[i].name; else break; }
-  if( code > 0 && code < 256 ) buf[0] = code; else buf[0] = '?';
-  return buf;
-  }
-
-
 bool is_editor_option( const int code )
   {
   switch( code )
@@ -169,14 +161,16 @@ bool is_editor_option( const int code )
   }
 
 
-bool set_option_from_code( const int code, const std::string & arg,
-                           File_options & file_options,
-                           const char * const msg,
+bool set_option_from_code( const Arg_parser & parser, const int argind,
+                           File_options & file_options, const char * const msg,
                            const bool allow_editor_options = false )
   {
+  const int code = parser.code( argind );
+  const char * const parsed_name = parser.parsed_name( argind ).c_str();
+  const std::string & arg = parser.argument( argind );
   if( !allow_editor_options && is_editor_option( code ) )
     { std::fprintf( stderr, "%serror: Option '%s' not allowed here.\n",
-                    msg, optname( code ) ); return false; }
+                    msg, parsed_name ); return false; }
 
   int errcode = 0, n;
   switch( code )
@@ -237,21 +231,22 @@ bool set_option_from_code( const int code, const std::string & arg,
 
   if( errcode == 1 )
     std::fprintf( stderr, "%serror: Bad argument for option '%s'\n",
-                  msg, optname( code ) );
+                  msg, parsed_name );
   else if( errcode == 2 )
     std::fprintf( stderr, "%serror: Value out of range for option '%s'\n",
-                  msg, optname( code ) );
+                  msg, parsed_name );
   return ( errcode == 0 );
   }
 
 
-int parse_line_col( const std::string & s, int & line, int & col )
+int parse_line_col( const std::string & s, long & line, long & col )
   {
-  int c = parse_int( s, line );
+  if( s == "+" ) { line = col = LONG_MAX - 1; return 1; }
+  int c = parse_long( s, line );
   if( c <= 0 || --line < 0 ) return 0;
   if( c < (int)s.size() )
     {
-    int i = parse_int( s.c_str() + c + 1, col );
+    int i = parse_long( s.c_str() + c + 1, col );
     if( i <= 0 || --col < 0 || s[c] != ',' ) return 0;
     c += i + 1;
     }
@@ -307,9 +302,9 @@ bool unwanted_name( const std::string & name )
   const char * const ext1[] = { "a", "o", "z", "Z", 0 };
   const char * const ext2[] = { "gz", "lz", "mo", "po", "ps", "so", "xz", 0 };
   const char * const ext3[] = { "bmp", "bz2", "deb", "dll", "dvi", "elf",
-    "gif", "gmo", "ico", "jar", "jpg", "obj", "pbm", "pdf", "pgm", "png",
-    "ppm", "rpm", "svg", "tar", "tgz", "tif", "tlz", "txz", "wav", "xcf",
-    "zip", 0 };
+    "exe", "gif", "gmo", "ico", "jar", "jpg", "obj", "pbm", "pdf", "pgm",
+    "png", "ppm", "rpm", "svg", "tar", "tgz", "tif", "tlz", "txz", "wav",
+    "xcf", "zip", 0 };
   const char * const ext4[] = { "info", "jpeg", "rpms", "svgz", 0 };
   const char * const ext5[] = { "class", 0 };
   const char * const * ext[5] = { ext1, ext2, ext3, ext4, ext5 };
@@ -330,7 +325,7 @@ bool unwanted_name( const std::string & name )
 
 // Depth first. Files first in each directory. Load regular files only.
 // Ignore backups '*~', unwanted names, and symbolic links.
-bool add_handles_recursively( std::string name, const int line, const int col,
+bool add_handles_recursively( std::string name, const long line, const long col,
                               const File_options & file_options,
                               bool & first_post, bool & read_error_found )
   {
@@ -419,7 +414,7 @@ void RC::apply_all_file_options( Buffer & buffer )
   }
 
 
-// Returns true if first non-whitespace character is '+' or '-'.
+// Return true if first non-whitespace character is '+' or '-'.
 bool RC::issigned( const std::string & s )
   {
   unsigned i = 0;
@@ -428,31 +423,40 @@ bool RC::issigned( const std::string & s )
   }
 
 
-// Returns the number of bytes read, or 0 if error.
+// Return the number of bytes read, or 0 if error.
 int RC::parse_int( const std::string & s, int & result )
+  {
+  long tmp;
+  const int c = parse_long( s, tmp );
+  if( !c || tmp < -INT_MAX || tmp > INT_MAX ) return 0;
+  result = tmp;
+  return c;
+  }
+
+// Return the number of bytes read, or 0 if error.
+int RC::parse_long( const std::string & s, long & result )
   {
   if( s.empty() ) return 0;
   const char * const str = s.c_str();
   char * tail;
   errno = 0;
   const long tmp = std::strtol( str, &tail, 0 );
-  if( errno || tail == str || tmp < -INT_MAX || tmp > INT_MAX ) return 0;
+  if( errno || tail == str || tmp < -LONG_MAX ) return 0;
   result = tmp;
   const int c = tail - str;
   return c;
   }
 
-
-// Returns the number of bytes read, or 0 if error.
-int RC::parse_relative_int( const std::string & s, int & result )
+// Return the number of bytes read, or 0 if error.
+int RC::parse_relative_long( const std::string & s, long & result )
   {
-  int tmp = 0;
-  const int c = parse_int( s, tmp );
+  long tmp = 0;
+  const int c = parse_long( s, tmp );
   if( !c ) return 0;
   if( !issigned( s ) ) result = tmp;
   else if( tmp > 0 )
     {
-    if( INT_MAX - tmp < result ) result = INT_MAX;
+    if( LONG_MAX - tmp < result ) result = LONG_MAX;
     else result += tmp;
     }
   else if( tmp < 0 )
@@ -464,7 +468,7 @@ int RC::parse_relative_int( const std::string & s, int & result )
   }
 
 
-// Returns 0 for success, 1 for file not found, 2 for syntax error.
+// Return 0 if success, 1 if file not found, 2 if syntax error.
 int RC::process_rcfile( const std::string & name )
   {
   FILE * const f = std::fopen( name.c_str(), "r" );
@@ -516,12 +520,12 @@ int RC::process_rcfile( const std::string & name )
         { std::fprintf( stderr, "%s%s\n", msg, parser.error().c_str() );
           retval = 2; }
       else if( regex_status == 0 )
-        { if( !set_option_from_code( parser.code( 0 ), parser.argument( 0 ),
+        { if( !set_option_from_code( parser, 0,
                                      moerc_file_options, msg, true ) )
             retval = 2; }
       else
         {
-        if( !set_option_from_code( parser.code( 0 ), parser.argument( 0 ),
+        if( !set_option_from_code( parser, 0,
                                    regex_options_vector.back().file_options,
                                    msg ) ) retval = 2;
         regex_status = 2;
@@ -534,7 +538,7 @@ int RC::process_rcfile( const std::string & name )
   }
 
 
-// Returns 0 if success, 1 if invalid option, 2 if a file can't be read.
+// Return 0 if success, 1 if invalid option, 2 if a file can't be read.
 int RC::process_options()
   {
   std::fputs( "Processing options... ", stderr );
@@ -543,14 +547,12 @@ int RC::process_options()
   int argind = 0;
   for( ; argind < parserp->arguments(); ++argind )
     {						// Process "global" options
-    const int code = parserp->code( argind );
-    if( !code ) break;				// line number or file name
-    if( !set_option_from_code( code, parserp->argument( argind ),
-                               default_file_options, "\n", true ) )
-      return 1;
+    if( !parserp->code( argind ) ) break;	// line number or file name
+    if( !set_option_from_code( *parserp, argind,
+                               default_file_options, "\n", true ) ) return 1;
     }
 
-  int line = 0, col = 0;
+  long line = 0, col = 0;
   bool first_post = true;
   bool read_error_found = false;
   bool unsupported_found = false;
@@ -573,17 +575,14 @@ int RC::process_options()
         return 1;
         }
       }
-//    else { line = 0; col = 0; }
     std::string name( parserp->argument( argind++ ) );
     Menu::tilde_expansion( name );
     File_options file_options;
     for( ; argind < parserp->arguments(); ++argind )
       {						// Process file options
-      const int code = parserp->code( argind );
-      if( !code ) break;			// line number or file name
-      if( !set_option_from_code( code, parserp->argument( argind ),
-                                 file_options, first_post ? "\n" : "" ) )
-        return 1;
+      if( !parserp->code( argind ) ) break;	// line number or file name
+      if( !set_option_from_code( *parserp, argind, file_options,
+                                 first_post ? "\n" : "" ) ) return 1;
       }
     bool can_read = false;
     const bool is_stdin = ( name == "-" );
