@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -50,19 +50,18 @@ Options & editor_options();			// Global editor options
 
 void apply_all_file_options( Buffer & buffer );
 
-// Returns true if first non-whitespace character is '+' or '-'.
+// Return true if first non-whitespace character is '+' or '-'.
 bool issigned( const std::string & s );
 
-// Returns the number of bytes read, or 0 if error.
+// Return the number of bytes read, or 0 if error.
 int parse_int( const std::string & s, int & result );
+int parse_long( const std::string & s, long & result );
+int parse_relative_long( const std::string & s, long & result );
 
-// Returns the number of bytes read, or 0 if error.
-int parse_relative_int( const std::string & s, int & result );
-
-// Returns 0 for success, 1 for file not found, 2 for syntax error.
+// Return 0 if success, 1 if file not found, 2 if syntax error.
 int process_rcfile( const std::string & name );
 
-// Returns 0 if success, 1 if invalid option, 2 if a file can't be read.
+// Return 0 if success, 1 if invalid option, 2 if a file can't be read.
 int process_options();
 
 int read_options( const int argc, const char * const argv[] );
