@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -108,8 +108,8 @@ inline int case_plus( const Basic_buffer & buffer, Point & p,
         {
         if( j >= counter )
           {
-          const int tmp = match_regex( buffer, p, regex, i + 1, pieces, icase );
-          if( tmp == 0 ) break; else if( tmp != 1 ) return 2;
+          const int ret = match_regex( buffer, p, regex, i + 1, pieces, icase );
+          if( ret == 0 ) break; else if( ret != 1 ) return 2;
           }
         const int ch2 = buffer.pgetc( p );
         if( ch2 < 0 || !set.includes( ch2 ) ) return 1;
@@ -125,8 +125,8 @@ inline int case_plus( const Basic_buffer & buffer, Point & p,
         {
         if( j >= counter )
           {
-          const int tmp = match_regex( buffer, p, regex, i + 1, pieces, icase );
-          if( tmp == 0 ) break; else if( tmp != 1 ) return 2;
+          const int ret = match_regex( buffer, p, regex, i + 1, pieces, icase );
+          if( ret == 0 ) break; else if( ret != 1 ) return 2;
           }
         const int ch2 = buffer.pgetc( p );
         if( ch2 < 0 || ( chr == 'w' ) != ISO_8859::isalnum_( ch2 ) ) return 1;
@@ -143,8 +143,8 @@ inline int case_plus( const Basic_buffer & buffer, Point & p,
     {
     if( j >= counter )
       {
-      const int tmp = match_regex( buffer, p, regex, i + 1, pieces, icase );
-      if( tmp == 0 ) break; else if( tmp != 1 ) return 2;
+      const int ret = match_regex( buffer, p, regex, i + 1, pieces, icase );
+      if( ret == 0 ) break; else if( ret != 1 ) return 2;
       }
     const int ch2 = buffer.pgetc( p );
     if( ch2 < 0 ||
@@ -157,10 +157,10 @@ inline int case_plus( const Basic_buffer & buffer, Point & p,
   }
 
 
-/* Returns 0 if a substring of 'buffer' beginning at 'p' matches 'regex[i]'.
-   If match, sets 'p' after the substring found and returns in 'pieces' the
+/* Return 0 if a substring of 'buffer' beginning at 'p' matches 'regex[i]'.
+   If match, set 'p' after the substring found and return in 'pieces' the
    text matching every '\*', '\?', etc, from the regular expresion.
-   Returns 1 if mismatch, 2 if regex syntax error.
+   Return 1 if mismatch, 2 if regex syntax error.
 */
 int match_regex( const Basic_buffer & buffer, Point & p,
                  const std::string & regex, unsigned i,
@@ -201,8 +201,8 @@ int match_regex( const Basic_buffer & buffer, Point & p,
                 std::string piece;
                 while( true )
                   {
-                  const int tmp = match_regex( buffer, p, regex, i + 1, pieces, icase );
-                  if( tmp != 1 ) { retval = tmp; break; }
+                  const int ret = match_regex( buffer, p, regex, i + 1, pieces, icase );
+                  if( ret != 1 ) { retval = ret; break; }
                   const int ch2 = buffer.pgetc( p );
                   if( ch2 < 0 ) { retval = 1; break; }
                   piece += ch2;
@@ -217,8 +217,8 @@ int match_regex( const Basic_buffer & buffer, Point & p,
                 const int ps = pieces.size();
                 while( true )
                   {
-                  const int tmp = match_regex( buffer, p, regex, i + 1, pieces, icase );
-                  if( tmp != 1 ) { retval = tmp; break; }
+                  const int ret = match_regex( buffer, p, regex, i + 1, pieces, icase );
+                  if( ret != 1 ) { retval = ret; break; }
                   const int ch2 = buffer.pgetc( p );
                   if( ch2 < 0 || ch2 == ')' || ch2 == ']' || ch2 == '}' )
                     { retval = 1; break; }
@@ -263,8 +263,8 @@ int match_regex( const Basic_buffer & buffer, Point & p,
                 std::string piece;
                 while( true )
                   {
-                  const int tmp = match_regex( buffer, p, regex, i + 1, pieces, icase );
-                  if( tmp != 1 ) { retval = tmp; break; }
+                  const int ret = match_regex( buffer, p, regex, i + 1, pieces, icase );
+                  if( ret != 1 ) { retval = ret; break; }
                   const int ch2 = buffer.pgetc( p );
                   if( ch2 < 0 || !ISO_8859::isspace( ch2 ) ) { retval = 1; break; }
                   piece += ch2;
@@ -313,11 +313,11 @@ int match_regex( const Basic_buffer & buffer, Point & p,
 } // end namespace Regex
 
 
-/* Searches 'buffer' from 'p1' ('p1-1' if backward) for 'regex'.
-   If found, sets 'p1' at the first char of, and 'p2' after the end of, the
-   substring found, and returns in 'pieces' the text matching every '\*',
+/* Search 'buffer' from 'p1' ('p1-1' if backward) for 'regex'.
+   If found, set 'p1' at the first char of, and 'p2' after the end of, the
+   substring found, and return in 'pieces' the text matching every '\*',
    '\?', etc, from the regular expresion.
-   Returns 0 if match, 1 if no match, 2 if trouble.
+   Return 0 if match, 1 if no match, 2 if trouble.
 */
 int Regex::find( const Basic_buffer & buffer, Point & p1, Point & p2,
                  const std::string & regex, std::vector< std::string > & pieces,
@@ -336,8 +336,8 @@ int Regex::find( const Basic_buffer & buffer, Point & p1, Point & p2,
       if( !buffer.rfind_text( p1, header, icase ) ) return 1;
       p2 = p1;
       if( same_size ) { buffer.pseek( p2, header.size() ); return 0; }
-      const int tmp = match_regex( buffer, p2, regex, 0, pieces, icase );
-      if( tmp != 1 ) return tmp;
+      const int ret = match_regex( buffer, p2, regex, 0, pieces, icase );
+      if( ret != 1 ) return ret;
       if( !buffer.pprev( p1 ) ) return 1;
       }
     else while( true )
@@ -345,8 +345,8 @@ int Regex::find( const Basic_buffer & buffer, Point & p1, Point & p2,
       if( !buffer.find_text( p1, header, icase ) ) return 1;
       p2 = p1; buffer.pseek( p1, -header.size() );
       if( same_size ) return 0; else p2 = p1;
-      const int tmp = match_regex( buffer, p2, regex, 0, pieces, icase );
-      if( tmp != 1 ) return tmp;
+      const int ret = match_regex( buffer, p2, regex, 0, pieces, icase );
+      if( ret != 1 ) return ret;
       if( !buffer.pnext( p1 ) || p1 == buffer.eof() ) return 1;
       }
     }
@@ -354,22 +354,22 @@ int Regex::find( const Basic_buffer & buffer, Point & p1, Point & p2,
   if( backward ) while( true )
     {
     if( !buffer.pprev( p1 ) ) return 1; else p2 = p1;
-    const int tmp = match_regex( buffer, p2, regex, 0, pieces, icase );
-    if( tmp != 1 ) return tmp;
+    const int ret = match_regex( buffer, p2, regex, 0, pieces, icase );
+    if( ret != 1 ) return ret;
     }
   else while( true )
     {
     p2 = p1;
-    const int tmp = match_regex( buffer, p2, regex, 0, pieces, icase );
-    if( tmp != 1 ) return tmp;
+    const int ret = match_regex( buffer, p2, regex, 0, pieces, icase );
+    if( ret != 1 ) return ret;
     if( !buffer.pnext( p1 ) || p1 == buffer.eof() ) return 1;
     }
   }
 
 
-/* Deletes block at [p1,p2) and replaces it with the text produced from
+/* Delete block at [p1,p2) and replace it with the text produced from
    'regex' and 'pieces'.
-   If there is no error, returns true and sets 'p2' after the newly
+   If there is no error, return true and set 'p2' after the newly
    inserted text.
 */
 bool Regex::replace( Buffer & buffer, const Point & p1, Point & p2,
@@ -421,7 +421,7 @@ bool Regex::replace( Buffer & buffer, const Point & p1, Point & p2,
   }
 
 
-// Returns true if 'regex' from i1 matches 'name' from i2
+// Return true if 'regex' from i1 matches 'name' from i2
 //
 bool Regex::match_filename( const std::string & regex, const std::string & name,
                             unsigned i1, unsigned i2 )
