@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,20 +17,20 @@
 
 namespace Regex {
 
-/* Searches 'buffer' from 'p1' ('p1-1' if backward) for 'regex'.
-   If found, sets 'p1' at the first char of, and 'p2' after the end of, the
-   substring found, and returns in 'pieces' the text matching every '\*',
+/* Search 'buffer' from 'p1' ('p1-1' if backward) for 'regex'.
+   If found, set 'p1' at the first char of, and 'p2' after the end of, the
+   substring found, and return in 'pieces' the text matching every '\*',
    '\?', etc, from the regular expresion.
-   Returns 0 if match, 1 if no match, 2 if trouble.
+   Return 0 if match, 1 if no match, 2 if trouble.
 */
 int find( const Basic_buffer & buffer, Point & p1, Point & p2,
           const std::string & regex, std::vector< std::string > & pieces,
           const bool icase = false, const bool backward = false );
 
 
-/* Deletes block at [p1,p2) and replaces it with the text produced from
+/* Delete block at [p1,p2) and replace it with the text produced from
    'regex' and 'pieces'.
-   If there is no error, returns true and sets 'p2' after the newly
+   If there is no error, return true and set 'p2' after the newly
    inserted text.
 */
 bool replace( Buffer & buffer, const Point & p1, Point & p2,
@@ -38,7 +38,7 @@ bool replace( Buffer & buffer, const Point & p1, Point & p2,
               const std::vector< std::string > & pieces );
 
 
-// Returns true if 'regex' from i1 matches 'name' from i2
+// Return true if 'regex' from i1 matches 'name' from i2
 //
 bool match_filename( const std::string & regex, const std::string & name,
                      unsigned i1 = 0, unsigned i2 = 0 );
