@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -263,6 +263,7 @@ const char * control_o_loop( int key )
                     last_key.compare_prev() ) ) { last_key.unset(); } break;
     case '8': msg = Window_vector::decode_quoted_printable_utf8( false,
                       last_key.compare_prev() ); break;
+    case 'B': msg = Window_vector::reformat_block(); break;
     case 'C': Window_vector::center_line(); break;
     case 'D': msg = Window_vector::remove_duplicate_lines(); break;
     case 'E': msg = Window_vector::remove_duplicate_lines( true ); break;
@@ -492,7 +493,7 @@ char * Screen::line_buf( int * const sizep )
 const char * Screen::clock_string() { return clock_string_; }
 
 
-// updates the clock
+// Update the clock.
 extern "C" void Screen::clock_handler( int sig )
   {
   const time_t tt = std::time( 0 );
@@ -527,7 +528,7 @@ extern "C" void Screen::clock_handler( int sig )
 int Screen::kbhit() { return read_key( false, false ); }
 
 
-/* Wait for a keystroke. Returns -1 if no key is available.
+/* Wait for a keystroke. Return -1 if no key is available.
    The clock only blinks when waiting here for a keystroke.
    The screen is mainly refreshed here (and in clock_handler).
    This function is the real "main loop" of the program.
@@ -553,7 +554,7 @@ int Screen::wait_kbhit( const int new_clock_limit, const bool get_key,
 
 /* 'history.back()' contains the default result (may be empty), and
    stores the result (if any).
-   Returns the size of the result string, 0 if none, -1 if aborted.
+   Return the size of the result string, 0 if none, -1 if aborted.
 */
 int Screen::get_string( const std::string & prompt,
                         std::vector< std::string > & history,
@@ -869,20 +870,20 @@ int Screen::user_loop( const char * const version_msg )
       {
       case  0: msg = Block::toggle_marking( w.buffer(), w.pointer() );
                break;						// ^SPACE
-      case  2: msg = Window_vector::reformat(); break;		// ^B
+      case  2: msg = Window_vector::reformat_paragraph(); break;	// ^B
       case  3: if( !Window_vector::close( true ) ) retval = 0; break;	// ^C
-      case  6: msg = Window_vector::search( key ); break;	// ^F
-      case  7: msg = Window_vector::search( key, true ); break;	// ^G
-      case 11: msg = control_k_loop( key ); break;		// ^K
-      case 15: msg = control_o_loop( key ); break;		// ^O
-      case 16: msg = user_control_char( key ); break;		// ^P
-      case 17: retval = control_q_loop( key, &msg ); break;	// ^Q
-      case 19: msg = control_s_loop( key, version_msg ); break;	// ^S
-      case 23: msg = Window_vector::search_word( key ); break;	// ^W
+      case  6: msg = Window_vector::search( key ); break;		// ^F
+      case  7: msg = Window_vector::search( key, true ); break;		// ^G
+      case 11: msg = control_k_loop( key ); break;			// ^K
+      case 15: msg = control_o_loop( key ); break;			// ^O
+      case 16: msg = user_control_char( key ); break;			// ^P
+      case 17: retval = control_q_loop( key, &msg ); break;		// ^Q
+      case 19: msg = control_s_loop( key, version_msg ); break;		// ^S
+      case 23: msg = Window_vector::search_word( key ); break;		// ^W
       case 24: if( !Window_vector::close( false ) ) retval = 0; break;	// ^X
-      case 25: Window_vector::delete_line(); break;		// ^Y
+      case 25: Window_vector::delete_line(); break;			// ^Y
       case 27: msg = alt_key_loop( key ); break;		// Alt or Esc
-      case 8:							// ^H
+      case 8:								// ^H
       case KEY_F(1) : Menu::help_menu( 8, KEY_F(1) ); break;
       case KEY_F(2) : msg = Window_vector::save_file( key ); break;
       case KEY_F(3) : msg = Window_vector::load_file( key ); break;
