@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -34,11 +34,11 @@ char * line_buf( int * const sizep );
 
 const char * clock_string();
 
-extern "C" void clock_handler( int sig );	// Updates the clock.
+extern "C" void clock_handler( int sig );	// Update the clock.
 
-int kbhit();			// Returns -1 if no key is available.
+int kbhit();		// Read key. Return -1 if no key is available.
 
-/* Wait for a keystroke. Returns -1 if no key is available.
+/* Wait for a keystroke. Return -1 if no key is available.
    The clock only blinks when waiting here for a keystroke.
    The screen is mainly refreshed here (and in clock_handler).
    This function is the real "main loop" of the program.
@@ -49,7 +49,7 @@ int wait_kbhit( const int new_clock_limit = -1, const bool get_key = true,
 
 /* 'history.back()' contains the default result (may be empty), and
    stores the result (if any).
-   Returns the size of the result string, 0 if none, -1 if aborted.
+   Return the size of the result string, 0 if none, -1 if aborted.
 */
 int get_string( const std::string & prompt,
                 std::vector< std::string > & history,
