@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -130,7 +130,7 @@ const char * Window::goto_line()
   const std::string & s = history.back();
   Point c = bhp->cursor;
   ++c.line;
-  if( !RC::parse_relative_int( s, c.line ) || c.line <= 0 )
+  if( !RC::parse_relative_long( s, c.line ) || c.line <= 0 )
     { history.pop_back(); return "Invalid line number"; }
   --c.line;
   if( c.line > bhp->buffer().last_line() ) c.line = bhp->buffer().last_line();
@@ -149,7 +149,7 @@ const char * Window::goto_column()
   const std::string & s = history.back();
   Point c = bhp->cursor;
   ++c.col;
-  if( !RC::parse_relative_int( s, c.col ) || c.col <= 0 )
+  if( !RC::parse_relative_long( s, c.col ) || c.col <= 0 )
     { history.pop_back(); return "Invalid column number"; }
   --c.col;
   update_points( c, true, false, from_cursor );
@@ -167,8 +167,8 @@ const char * Window::goto_offset()
     return 0;
   const std::string & s = history.back();
   const bool relative = RC::issigned( s );
-  int offset = 0;
-  if( !RC::parse_int( s, offset ) || ( !relative && offset < 0 ) )
+  long offset = 0;
+  if( !RC::parse_long( s, offset ) || ( !relative && offset < 0 ) )
     { history.pop_back(); return "Invalid offset value"; }
   const int cr = buffer.crlf;
   Point p( 0, 0 );
@@ -178,7 +178,7 @@ const char * Window::goto_offset()
     {
     while( p.line < buffer.last_line() )
       {
-      const int c = buffer.characters( p.line );
+      const long c = buffer.characters( p.line );
       if( p.col < c + cr ) { p.col = std::min( p.col, c - 1 ); break; }
       p.col -= c + cr; ++p.line;
       }
@@ -188,7 +188,7 @@ const char * Window::goto_offset()
     {
     while( p.line > 0 )
       {
-      const int c = buffer.characters( --p.line );
+      const long c = buffer.characters( --p.line );
       p.col += c + cr;
       if( p.col >= 0 ) { p.col = std::min( p.col, c - 1 ); break; }
       }
@@ -283,7 +283,7 @@ void Window::move_page( const bool down, const bool scroll )
 void Window::move_vertical( const int lines )
   {
   Point c = bhp->cursor;
-  const int last_line = bhp->buffer().last_line();
+  const long last_line = bhp->buffer().last_line();
 
   if( lines < 0 )
     {
@@ -322,7 +322,7 @@ void Window::scroll_vertical( const int lines )
     { if( tl.line == 0 ) { return; } tl.line += lines; tl.cut(); }
   else if( lines > 0 )
     {
-    const int first_line = bhp->buffer().lines() - 2;
+    const long first_line = bhp->buffer().lines() - 2;
     if( first_line < 0 || tl.line == first_line ) return;
     tl.line += lines; if( tl.line > first_line ) tl.line = first_line;
     }
@@ -378,13 +378,13 @@ const char * Window::show_character_info() const
   const int ch = buffer[p];
 
   if( ch < 0 && p != buffer.eof() )
-    snprintf( buf, bufsize, "*** Error: Bad Pointer: Line %d  Pos %d",
+    snprintf( buf, bufsize, "*** Error: Bad Pointer: Line %ld  Pos %ld",
               p.line + 1, p.col + 1 );
   else
     {
     int percent = 0;
     long offset = buffer.character_offset( p, percent );
-    const int len = snprintf( buf, bufsize, "Line %d  Pos %d  Offset %ld(0x%lX)  %d%%  ",
+    const int len = snprintf( buf, bufsize, "Line %ld  Pos %ld  Offset %ld(0x%lX)  %d%%  ",
                               p.line + 1, p.col + 1, offset, offset, percent );
     if( len > 0 && len < bufsize )
       {
@@ -469,7 +469,7 @@ const char * Window::show_utf8_code()
   else if( p == buffer.eof() )
     snprintf( buf, bufsize, "(End Of File)" );
   else
-    snprintf( buf, bufsize, "*** Error: Bad Pointer: Line %d  Pos %d",
+    snprintf( buf, bufsize, "*** Error: Bad Pointer: Line %ld  Pos %ld",
               p.line + 1, p.col + 1 );
   return buf;
   }
@@ -484,9 +484,9 @@ void Window::show_status_line( const char * const prefix ) const
   int bufsize = 0;
   char * const buf = Screen::line_buf( &bufsize );
   int offset = bufsize - 41;
-  const int line = bhp->pcursor.line + 1, col = bhp->pcursor.col + 1;
-  for( int i = line; i > 9999; i /= 10 ) --offset;
-  for( int i = col; i > 999; i /= 10 ) --offset;
+  const long line = bhp->pcursor.line + 1, col = bhp->pcursor.col + 1;
+  for( long i = line; i > 9999; i /= 10 ) --offset;
+  for( long i = col; i > 999; i /= 10 ) --offset;
   const char * name = buffer.nename().c_str();
   const int overlap = buffer.nename().size() + 11 - offset;
   if( overlap > 0 ) name += overlap;
@@ -502,7 +502,7 @@ void Window::show_status_line( const char * const prefix ) const
                             modified ? " (Modified)" : "" );
   if( len > 0 && len < offset ) std::memset( buf + len, ' ', offset - len );
   snprintf( buf + offset, bufsize - offset,
-            "  Line %-4d Col %-3d %5s   F1 for help",
+            "  Line %-4ld Col %-3ld %5s   F1 for help",
             line, col, Screen::clock_string() );
   if( RC::editor_options().show_code_lpos )
     {
@@ -555,19 +555,19 @@ void Window::update_points( const Point & to, const bool show,
     {
     const int d = center ? ( height_ - 2 ) / 2 :
                   height_ - ( ( c.line >= buffer.last_line() ) ? 2 : 3 );
-    tl.line = std::max( 0, c.line - d );
+    tl.line = std::max( 0L, c.line - d );
     }
   else if( rc.line < 1 )
     {
     const int d = center ? ( height_ - 2 ) / 2 : 1;
-    tl.line = std::max( 0, c.line - d );
+    tl.line = std::max( 0L, c.line - d );
     }
-  const int ahead = std::max( 1, std::min( 8,
-                                 buffer.characters( p.line ) - p.col ) );
+  const int ahead = std::max( 1L, std::min( 8L,
+                                  buffer.characters( p.line ) - p.col ) );
   if( rc.col + ahead > Screen::width() || center )
-    tl.col = std::max( 0, c.col + ahead - Screen::width() );
+    tl.col = std::max( 0L, c.col + ahead - Screen::width() );
   else if( rc.col < 8 )
-    tl.col = std::max( 0, c.col - 8 );
+    tl.col = std::max( 0L, c.col - 8 );
 
   if( show ) { if( tl == old_tl ) show_status_line(); else repaint(); }
   }
