@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2021 Antonio Diaz Diaz.
+   Copyright (C) 2005-2022 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -215,21 +215,25 @@ int Window_vector::init()
   }
 
 
-/* 'new_size' == 0: reload same number of windows
-   'new_size' < 0: toggle 1 window <--> max_windows
+Window & Window_vector::curwin() { return data[curwin_]; }
+int Window_vector::windows() { return data.size(); }
+
+
+/* If 'new_size' == 0, reload same number of windows.
+   If 'new_size' < 0, toggle 1 window <--> max_windows.
+   Center cursor the first time each handle is displayed.
 */
 int Window_vector::load( int new_size )
   {
   const int handles = Bufhandle_vector::handles();
   const bool toggle = ( new_size < 0 && handles > 1 );
-  const bool center = data.empty();			// center all on init
 
   if( !handles ) { curwin_ = 0; data.clear(); return 0; }
-  if( new_size == 0 ) new_size = data.size();
+  if( new_size == 0 ) new_size = windows();
   else if( new_size < 0 )
     {
     for( int i = 0; i < curwin_; ++i ) Bufhandle_vector::next();
-    new_size = ( data.size() != 1 ) ? 1 : handles;
+    new_size = ( windows() != 1 ) ? 1 : handles;
     curwin_ = 0;
     }
   new_size = std::min( new_size, handles );
@@ -244,14 +248,16 @@ int Window_vector::load( int new_size )
   int i = 0, y = 0;
   while( i + 1 < new_size )
     {
-    data.push_back( Window( Bufhandle_vector::handle( i ), y, wheight, center ) );
+    data.push_back( Window( Bufhandle_vector::handle( i ), y, wheight,
+                            Bufhandle_vector::handle( i ).first_post() ) );
     ++i; y += wheight;
     }
   data.push_back( Window( Bufhandle_vector::handle( i ), y,
-                          Screen::height() - y, center ) );
-  if( toggle && data.size() == 1 ) data[0].center_cursor();
-  for( i = 0; i < (int)data.size(); ++i ) data[i].repaint();
-  return data.size();
+                          Screen::height() - y,
+                          Bufhandle_vector::handle( i ).first_post() ) );
+  if( toggle && windows() == 1 ) data[0].center_cursor();
+  for( i = 0; i < windows(); ++i ) data[i].repaint();
+  return windows();
   }
 
 
@@ -264,7 +270,7 @@ void Window_vector::bufhandle_menu( const int abort_key )
 
 const char * Window_vector::change_buffer_name()
   {
-  Buffer & buffer = data[curwin_].buffer();
+  Buffer & buffer = curwin().buffer();
   std::string name( buffer.name() );
 
   if( Menu::get_filename( "New buffer name (^C to abort): ", name ) < 0 ||
@@ -309,9 +315,8 @@ void Window_vector::split_window()
 
 const char * Window_vector::save_file( const int abort_key )
   {
-  const Buffer & buffer = data[curwin_].buffer();
-  std::string name( buffer.name() );
-  if( name.empty() && read_only( buffer ) ) return 0;
+  const Buffer & buffer = curwin().buffer();
+  std::string name( buffer.name() );		// name may be empty (unnamed)
 
   if( Menu::get_filename( "Name of file to save (^C to abort): ",
       name, abort_key ) <= 0 )
@@ -330,20 +335,20 @@ const char * Window_vector::save_file( const int abort_key )
               Screen::cut_filename( name, 13 ) );
     return buf;
     }
-  if( !read_only( buffer ) ) return "File not saved";
+  if( name != buffer.name() || !read_only( buffer ) ) return "File not saved";
   return 0;
   }
 
 
-// Returns number of windows, 0 if none, -1 if aborted.
+// Return number of windows, 0 if none, -1 if aborted.
 //
 int Window_vector::close( bool abort, const bool quiet )
   {
   if( !abort || !quiet )
     {
-    Buffer_handle & bh = data[curwin_].buffer_handle();
-    const bool last_handle = Bufhandle_vector::handles( bh.buffer() ) <= 1;
-    const bool modified = bh.buffer().modified();
+    Buffer & buffer = curwin().buffer();
+    const bool last_handle = Bufhandle_vector::handles( buffer ) <= 1;
+    const bool modified = buffer.modified();
     const bool exit_ask = RC::editor_options().exit_ask && !quiet;
 
     if( abort && modified && last_handle )
@@ -355,16 +360,16 @@ int Window_vector::close( bool abort, const bool quiet )
       }
     if( !abort && modified )
       {
-      if( read_only( bh.buffer() ) ) return -1;
-      std::string name( bh.buffer().name() );
+      if( read_only( buffer ) ) return -1;
+      std::string name( buffer.name() );
       if( ( exit_ask || name.empty() ) &&
           Menu::get_filename( "Name of file to save (^C to abort): ",
                               name ) <= 0 ) return -1;
       if( name.empty() ) return -1;
-      try { if( !bh.buffer().save( &name ) ) return -1; }
+      try { if( !buffer.save( &name ) ) return -1; }
       catch( Buffer::Error & e )
         { if( !quiet ) Screen::show_message( e.msg ); return -1; }
-      if( Bufhandle_vector::handles() <= 1 ) data[curwin_].show_status_line();
+      if( Bufhandle_vector::handles() <= 1 ) curwin().show_status_line();
       }
     else if( exit_ask && last_handle && !modified )
       {
@@ -393,24 +398,28 @@ int Window_vector::close_and_exit( const bool abort )
       Bufhandle_vector::save_all_named();
       for( int i = Bufhandle_vector::handles(); i > 0; next(), --i )
         {
-        const Buffer & buffer = data[curwin_].buffer();
+        const Buffer & buffer = curwin().buffer();
         if( buffer.modified() )
           {
-          if( read_only( buffer ) ) return data.size();	//can't save
+          if( read_only( buffer ) ) return windows();	//can't save
           const char * const msg = save_file();
           if( buffer.modified() )			// not saved
-            { if( msg ) Screen::show_message( msg ); return data.size(); }
+            { if( msg ) Screen::show_message( msg ); return windows(); }
           }
         }
       }
-    if( data.size() > 1 ) load( 1 );
+    if( windows() > 1 ) load( 1 );
     Bufhandle_vector::delete_all_handles(); curwin_ = 0; data.clear();
     }
-  return data.size();
+  return windows();
   }
 
 
-Window & Window_vector::curwin() { return data[curwin_]; }
+Window & Window_vector::window( int i )
+  {
+  if( i < 0 ) i = 0; else if( i >= windows() ) i = windows() - 1;
+  return data[i];
+  }
 
 
 void Window_vector::last_visited()
@@ -447,29 +456,19 @@ void Window_vector::prev()
   }
 
 
-Window & Window_vector::window( int i )
-  {
-  if( i < 0 ) i = 0; else if( i >= windows() ) i = windows() - 1;
-  return data[i];
-  }
-
-
-int Window_vector::windows() { return data.size(); }
-
-
 const char * Window_vector::add_char( const int key, const bool force )
   {
-  Window & w = data[curwin_];
+  Window & w = curwin();
   if( w.buffer().options.read_only )
     {
-    if( !force ) switch( key )
+    if( !force ) switch( key )			// basic less emulation
       {
       case ' ': w.move_vertical( w.height() - 2 ); return 0;
       case '/': return search( 6 );				// ^F
       case 'n': return search( 7, true, "", 0 );		// ^G -->
       case 'N': return search( 7, true, "", 1 );		// ^G <--
       }
-    read_only( w.buffer() );
+    read_only( w.buffer() );			// show feedback
     return 0;
     }
 
@@ -490,17 +489,16 @@ const char * Window_vector::add_char( const int key, const bool force )
 
 void Window_vector::delete_char( const bool back )
   {
-  Window & w = data[curwin_];
-  Point & p = w.pointer();
+  Window & w = curwin();
 
-  if( !read_only( w.buffer() ) && w.buffer().pdelc( p, back ) )
+  if( !read_only( w.buffer() ) && w.buffer().pdelc( w.pointer(), back ) )
     Screen::repaint( &w.buffer() );
   }
 
 
 void Window_vector::delete_line()
   {
-  Window & w = data[curwin_];
+  Window & w = curwin();
 
   if( !read_only( w.buffer() ) && w.buffer().pdell( w.pointer() ) )
     Screen::repaint( &w.buffer() );
@@ -509,23 +507,21 @@ void Window_vector::delete_line()
 
 void Window_vector::copy_block()
   {
-  Window & w = data[curwin_];
+  Window & w = curwin();
+  if( no_block() || read_only( w.buffer() ) ) return;
 
-  if( !no_block() && !read_only( w.buffer() ) )
+  const Buffer & buffer = *Block::bufferp();
+  if( Block::copy_block( w.buffer(), w.pointer() ) )
     {
-    const Buffer & buffer = *Block::bufferp();
-    if( Block::copy_block( w.buffer(), w.pointer() ) )
-      {
-      if( &buffer != &w.buffer() ) Screen::repaint( &buffer );
-      Screen::repaint( &w.buffer() );
-      }
+    if( &buffer != &w.buffer() ) Screen::repaint( &buffer );
+    Screen::repaint( &w.buffer() );
     }
   }
 
 
 void Window_vector::delete_block()
   {
-  Buffer & buffer = data[curwin_].buffer();
+  Buffer & buffer = curwin().buffer();
 
   if( !no_block() && !no_block_in_this_file( buffer ) &&
       !read_only( buffer ) && Block::delete_block() )
@@ -535,7 +531,7 @@ void Window_vector::delete_block()
 
 void Window_vector::move_block()
   {
-  Window & w = data[curwin_];
+  Window & w = curwin();
   Point & p = w.pointer();
 
   if( !no_block() && !Block::in_block_or_end( w.buffer(), p ) )
@@ -553,7 +549,7 @@ void Window_vector::move_block()
 
 const char * Window_vector::read_block()
   {
-  Window & w = data[curwin_];
+  Window & w = curwin();
   if( read_only( w.buffer() ) ) return 0;
 
   std::string name;
@@ -608,10 +604,10 @@ const char * Window_vector::write_block()
 
 void Window_vector::indent_block()
   {
-  Buffer & buffer = data[curwin_].buffer();
-
+  Buffer & buffer = curwin().buffer();
   if( no_block() || no_block_in_this_file( buffer ) || rectangular_block() ||
       read_only( buffer ) ) return;
+
   Point p = Block::begin();
   bool first_post = true;
   const bool ow = buffer.options.overwrite;
@@ -637,10 +633,10 @@ void Window_vector::indent_block()
 
 const char * Window_vector::unindent_block()
   {
-  Buffer & buffer = data[curwin_].buffer();
-
+  Buffer & buffer = curwin().buffer();
   if( no_block() || no_block_in_this_file( buffer ) || rectangular_block() ||
       read_only( buffer ) ) return 0;
+
   Point p = Block::begin();
   bool fail = false;
   while( buffer.bol( p ) < Block::end() && !fail )
@@ -659,13 +655,13 @@ const char * Window_vector::unindent_block()
   p = Block::begin();
   while( buffer.bol( p ) < Block::end() )
     {
-    const int target_col = buffer.to_cursor( buffer.bot( p ) ).col -
-                           RC::editor_options().indent_step();
+    const long target_col = buffer.to_cursor( buffer.bot( p ) ).col -
+                            RC::editor_options().indent_step();
     if( buffer.eol( p ).col > 0 )
       while( true )
         {
         p = buffer.bot( p );
-        const int col = buffer.to_cursor( p ).col;
+        const long col = buffer.to_cursor( p ).col;
         if( col > target_col )
           {
           if( first_post ) first_post = false; else buffer.force_append();
@@ -690,7 +686,7 @@ const char * Window_vector::unindent_block()
 
 const char * Window_vector::undo()
   {
-  Window & w = data[curwin_];
+  Window & w = curwin();
 
   if( !read_only( w.buffer() ) )
     {
@@ -703,7 +699,7 @@ const char * Window_vector::undo()
 
 const char * Window_vector::redo()
   {
-  Window & w = data[curwin_];
+  Window & w = curwin();
 
   if( !read_only( w.buffer() ) )
     {
@@ -716,117 +712,101 @@ const char * Window_vector::redo()
 
 void Window_vector::center_line()
   {
-  Window & w = data[curwin_];
+  Window & w = curwin();
   Buffer & buffer = w.buffer();
   const Point bol = buffer.bol( w.pointer() );
   const Point bot = buffer.bot( bol );
   const Point cbot = buffer.to_cursor( bot );
   const Point ceot = buffer.to_cursor( buffer.eot( bol ) );
-  int l = cbot.col - buffer.options.lmargin();
-  int r = buffer.options.rmargin() - ceot.col;
+  long l = cbot.col - buffer.options.lmargin();
+  long r = buffer.options.rmargin() - ceot.col;
 
-  if( !read_only( buffer ) && cbot < ceot && l != r && l != r + 1 )
+  if( read_only( buffer ) || cbot >= ceot || l == r || l == r + 1 ) return;
+  buffer.reset_appendable();
+  const long off = ( bot != cbot ) ? cbot.col : 0;
+  if( off )
+    { buffer.pdelb( bol, bot ); l -= off; r += off; buffer.force_append(); }
+  else if( l > r + 1 && bot.col > 0 )
+    buffer.pdelb( bol, Point( bot.line, std::min( bot.col, ( l - r ) / 2 ) ) );
+  if( l < r )
     {
-    buffer.reset_appendable();
-    const int off = ( bot != cbot ) ? cbot.col : 0;
-    if( off )
-      { buffer.pdelb( bol, bot ); l -= off; r += off; buffer.force_append(); }
-    else if( l > r + 1 && bot.col > 0 )
-      buffer.pdelb( bol, Point( bot.line, std::min( bot.col, ( l - r ) / 2 ) ) );
-    if( l < r )
-      {
-      const bool ow = buffer.options.overwrite;
-      buffer.options.overwrite = false;
-      Point p = bol;
-      for( ; l < r; ++l, --r ) buffer.pputc( p, ' ' );
-      buffer.options.overwrite = ow;
-      }
-    buffer.reset_appendable();
-    Screen::repaint( &buffer );
+    const bool ow = buffer.options.overwrite;
+    buffer.options.overwrite = false;
+    Point p = bol;
+    for( ; l < r; ++l, --r ) buffer.pputc( p, ' ' );
+    buffer.options.overwrite = ow;
     }
+  buffer.reset_appendable();
+  Screen::repaint( &buffer );
   }
 
 
-const char * Window_vector::reformat()
+const char * Window_vector::reformat_paragraph()
   {
-  Window & w = data[curwin_];
-  Buffer_handle & bh = w.buffer_handle();
-  Buffer & buffer = bh.buffer();
-  const Point bop = buffer.bop( bh.pointer );	// begin of paragraph
-  const Point eop = buffer.eop( bh.pointer );	// end of paragraph
-  const Point bot = buffer.bot( bop );		// begin of text in line
+  Window & w = curwin();
+  Buffer & buffer = w.buffer();
+  if( read_only( buffer ) ) return 0;
 
-  if( !read_only( buffer ) && bop < eop )
-    {
-    const int rmargin = buffer.options.rmargin();
-    const int lmargin = std::max( buffer.options.lmargin(),
-                                  std::min( rmargin - 1, bh.cursor.col ) );
-    Buffer tmp;
-    tmp.options.set_rmargin( rmargin );
-    tmp.options.auto_indent = false;
-    tmp.options.overwrite = false;
-    tmp.options.word_wrap = true;
-    Point dummy = tmp.bof();
-    if( bop < bot && buffer.to_cursor( bot ).col > lmargin )
-      tmp.Basic_buffer::pputb( dummy, buffer, bop, bot );
-    tmp.options.set_lmargin( lmargin );
-    bool period2 = false;	// prev char was period in 2 spaces mode
-    bool pending_space = false;
-    bool change = false;
-    for( Point p = bot; p < eop; )
+  Point cursor = w.buffer_handle().cursor;
+  try {
+    if( buffer.reformat_paragraph( cursor, false ) )
       {
-      unsigned char ch = buffer.pgetc( p );
-      if( std::isspace( ch ) )			// exclude no-break space
-        {
-        if( ( ch != ' ' && ch != '\n' ) ) change = true;
-        pending_space = true;
-        }
-      else
-        {
-        if( pending_space )
-          { pending_space = false; tmp.pputc( dummy, ' ' );
-            if( period2 ) tmp.pputc( dummy, ' ' ); }
-        tmp.pputc( dummy, ch ); dummy = tmp.eof();
-        period2 = ( ch == '.' && buffer.options.two_spaces );
-        }
-      if( Screen::kbhit() >= 0 && Screen::wait_kbhit() == 3 )
-        return "Aborted";
-      }
-    if( dummy != tmp.bol( dummy ) ) tmp.pputc( dummy, '\n' );
-    if( !change ) change = ( tmp.last_line() != ( eop.line - bop.line ) );
-    if( !change )
-      for( int line = 0; line < tmp.lines(); ++line )
-        if( tmp.characters( line ) != buffer.characters( bop.line + line ) &&
-            ( !tmp.blank( line ) || !buffer.blank( bop.line + line ) ) )
-          { change = true; break; }
-    // detect changes that do not change total number of spaces in line
-    if( !change && buffer.options.two_spaces )
-      for( int line = 0; line < tmp.lines(); ++line )
-        if( tmp.get_line( line ) != buffer.get_line( bop.line + line ) &&
-            ( !tmp.blank( line ) || !buffer.blank( bop.line + line ) ) )
-          { change = true; break; }
-    if( change )
-      {
-      buffer.reset_appendable();
-      Point p = eop;
-      buffer.replace( bop, p, tmp, tmp.bof(), tmp.eof() );
       buffer.reset_appendable();
       Screen::repaint( &buffer );
-      p.line = bop.line; p.col = lmargin;
-      w.update_points( p, true, false, Window::from_cursor );
+      w.update_points( cursor, true, false, Window::from_cursor );
       }
     }
+  catch( Buffer::Error & e ) { return e.msg; }
   return 0;
   }
 
 
-// Can't use to_lowercase, etc, because of rectangle mode.
-// Can't change characters in place because of atomic undo.
+const char * Window_vector::reformat_block()
+  {
+  Window & w = curwin();
+  Buffer & buffer = w.buffer();
+  if( no_block() || no_block_in_this_file( buffer ) || rectangular_block() ||
+      read_only( buffer ) ) return 0;
+
+  const char * msg = 0;
+  Point cursor = w.buffer_handle().cursor;
+  cursor.line = Block::begin().line;			// keep cursor col
+  const bool incomplete = Block::end().col > 0;
+  bool change = false;
+  Screen::show_feedback( "reformating..." );
+  while( cursor.line < Block::end().line + incomplete &&
+         cursor.line < buffer.lines() )
+    if( buffer.blank( cursor.line ) ) ++cursor.line;
+    else
+      {
+      try { if( buffer.reformat_paragraph( cursor, change ) ) change = true; }
+      catch( Buffer::Error & e )
+        { if( change ) { msg = e.msg; break; }
+          else { w.repaint(); return e.msg; } }	// remove feedback
+      cursor.line = buffer.eop( cursor ).line;	// end of paragraph, keep col
+      }
+  if( change )
+    {
+    buffer.reset_appendable();
+    Screen::repaint( &buffer );
+    if( !msg ) cursor.line = buffer.bop( Block::begin() ).line;
+    w.update_points( cursor, true, false, Window::from_cursor );
+    }
+  else { w.repaint();				// remove feedback
+         if( !msg ) msg = "Paragraphs in block are already reformatted"; }
+  return msg;
+  }
+
+
+/* Can't use to_lowercase, etc, because of rectangle mode.
+   Can't change characters in place because of atomic undo.
+*/
 const char * Window_vector::change_case( const int caps_level )
   {
-  Buffer & buffer = data[curwin_].buffer();
+  Buffer & buffer = curwin().buffer();
   if( no_block() || no_block_in_this_file( buffer ) || read_only( buffer ) )
     return 0;
+
   Basic_buffer tmp;
   Point p = tmp.bof();
   bool change = false;
@@ -861,16 +841,17 @@ const char * Window_vector::change_case( const int caps_level )
 
 void Window_vector::encode_base64()
   {
-  Buffer & buffer = data[curwin_].buffer();
+  Buffer & buffer = curwin().buffer();
   if( no_block() || no_block_in_this_file( buffer ) || rectangular_block() ||
       read_only( buffer ) ) return;
+
   std::string in, out;
   Block::bufferp()->to_string( Block::begin(), Block::end(), in );
   Encoding::base64_encode( in, out );
   Basic_buffer tmp;
   Point p = tmp.bof();
   int c = 0;
-  for( unsigned i = 0; i < out.size(); ++i )
+  for( unsigned long i = 0; i < out.size(); ++i )
     {
     tmp.pputc( p, out[i] );
     if( ++c >= 76 ) { c = 0; tmp.pputc( p, '\n' ); }
@@ -882,15 +863,16 @@ void Window_vector::encode_base64()
 
 const char * Window_vector::decode_base64()
   {
-  Buffer & buffer = data[curwin_].buffer();
+  Buffer & buffer = curwin().buffer();
   if( no_block() || no_block_in_this_file( buffer ) || rectangular_block() ||
       read_only( buffer ) ) return 0;
+
   std::string in, out;
   Block::bufferp()->to_string( Block::begin(), Block::end(), in );
-  for( int i = in.size() - 1; i >= 0; --i )
+  for( long i = in.size() - 1; i >= 0; --i )
     if( ISO_8859::isspace( in[i] ) )
       in.erase( i, 1 );
-  int idx;
+  long idx;
   if( !Encoding::base64_decode( in, out, &idx ) )
     {
     Block::disable_marking();
@@ -898,12 +880,12 @@ const char * Window_vector::decode_base64()
     while( idx > 0 ) if( !ISO_8859::isspace( buffer.pgetc( p ) ) ) --idx;
     while( ISO_8859::isspace( buffer[p] ) ) buffer.pnext( p );
     if( idx == 0 && buffer.pisvalid( p ) )
-      data[curwin_].update_points( p, true, true );
+      curwin().update_points( p, true, true );
     return "Invalid Base64 data in block";
     }
   Basic_buffer tmp;
   Point p = tmp.bof();
-  for( unsigned i = 0; i < out.size(); ++i )
+  for( unsigned long i = 0; i < out.size(); ++i )
     tmp.pputc( p, out[i] );
   replace_and_repaint( buffer, tmp );
   return 0;
@@ -913,9 +895,10 @@ const char * Window_vector::decode_base64()
 bool Window_vector::encode_ascii_utf8( const char ** const msgp,
                                        const bool mode_a, const bool force )
   {
-  Buffer & buffer = data[curwin_].buffer();
+  Buffer & buffer = curwin().buffer();
   if( no_block() || no_block_in_this_file( buffer ) || rectangular_block() ||
       read_only( buffer ) ) { *msgp = 0; return false; }
+
   std::string in, out;
   Block::bufferp()->to_string( Block::begin(), Block::end(), in );
   if( mode_a && !Encoding::ascii_encode( in, out ) )
@@ -924,7 +907,7 @@ bool Window_vector::encode_ascii_utf8( const char ** const msgp,
     { *msgp = "Text in block is already UTF-8 encoded"; return false; }
   Basic_buffer tmp;
   Point p = tmp.bof();
-  for( unsigned i = 0; i < out.size(); ++i )
+  for( unsigned long i = 0; i < out.size(); ++i )
     tmp.pputc( p, out[i] );
   replace_and_repaint( buffer, tmp );
   *msgp = "Done";
@@ -935,38 +918,39 @@ bool Window_vector::encode_ascii_utf8( const char ** const msgp,
 const char * Window_vector::decode_quoted_printable_utf8( const bool mode_q,
                                                           const bool force )
   {
-  Buffer & buffer = data[curwin_].buffer();
+  Buffer & buffer = curwin().buffer();
   if( no_block() || no_block_in_this_file( buffer ) || rectangular_block() ||
       read_only( buffer ) ) return 0;
+
   std::string in, out;
   Block::bufferp()->to_string( Block::begin(), Block::end(), in );
   if( mode_q )
     {
-    int idx;
+    long idx;
     if( !Encoding::quoted_printable_decode( in, out, &idx ) )
       {
       Block::disable_marking();
       Point p = Block::begin();
       if( buffer.pisvalid( p ) && buffer.pseek( p, idx ) )
-        data[curwin_].update_points( p, true, true );
+        curwin().update_points( p, true, true );
       return "Invalid Quoted-Printable data in block";
       }
     }
   else
     {
-    int idx;
-    const int tmp = Encoding::utf8_decode( in, out, &idx, force );
-    if( tmp != 0 )
+    long idx;
+    const int ret = Encoding::utf8_decode( in, out, &idx, force );
+    if( ret != 0 )
       {
       Block::disable_marking();
       Point p = Block::begin();
       if( buffer.pisvalid( p ) && buffer.pseek( p, idx ) )
-        data[curwin_].update_points( p, true, true );
-      if( tmp > 0 )
+        curwin().update_points( p, true, true );
+      if( ret > 0 )
         {
         int bufsize = 0;
         char * const buf = Screen::line_buf( &bufsize );
-        snprintf( buf, bufsize, "UTF-8 code 'U%04X' out of range in block", tmp );
+        snprintf( buf, bufsize, "UTF-8 code 'U%04X' out of range in block", ret );
         return buf;
         }
       else
@@ -976,7 +960,7 @@ const char * Window_vector::decode_quoted_printable_utf8( const bool mode_q,
   if( in == out ) return "Text in block is already decoded";
   Basic_buffer tmp;
   Point p = tmp.bof();
-  for( unsigned i = 0; i < out.size(); ++i )
+  for( unsigned long i = 0; i < out.size(); ++i )
     tmp.pputc( p, out[i] );
   replace_and_repaint( buffer, tmp );
   return "Done";
@@ -985,12 +969,13 @@ const char * Window_vector::decode_quoted_printable_utf8( const bool mode_q,
 
 const char * Window_vector::remove_utf8_out_of_range()
   {
-  Buffer & buffer = data[curwin_].buffer();
+  Buffer & buffer = curwin().buffer();
   if( no_block() || no_block_in_this_file( buffer ) || rectangular_block() ||
       read_only( buffer ) ) return 0;
+
   std::string in, out;
   Block::bufferp()->to_string( Block::begin(), Block::end(), in );
-  int idx;
+  long idx;
   const int ret = Encoding::remove_utf8_out_of_range( in, out, &idx );
   if( ret == 0 ) return "Text in block is already decoded";
   if( ret < 0 )
@@ -998,12 +983,12 @@ const char * Window_vector::remove_utf8_out_of_range()
     Block::disable_marking();
     Point p = Block::begin();
     if( buffer.pisvalid( p ) && buffer.pseek( p, idx ) )
-      data[curwin_].update_points( p, true, true );
+      curwin().update_points( p, true, true );
     return "Invalid UTF-8 data in block";
     }
   Basic_buffer tmp;
   Point p = tmp.bof();
-  for( unsigned i = 0; i < out.size(); ++i )
+  for( unsigned long i = 0; i < out.size(); ++i )
     tmp.pputc( p, out[i] );
   replace_and_repaint( buffer, tmp );
   return "Done";
@@ -1012,9 +997,10 @@ const char * Window_vector::remove_utf8_out_of_range()
 
 void Window_vector::encode_rot1347( const bool mode13 )
   {
-  Buffer & buffer = data[curwin_].buffer();
+  Buffer & buffer = curwin().buffer();
   if( no_block() || no_block_in_this_file( buffer ) || rectangular_block() ||
       read_only( buffer ) ) return;
+
   Basic_buffer tmp;
   Point p = tmp.bof();
   if( mode13 )
@@ -1029,17 +1015,18 @@ void Window_vector::encode_rot1347( const bool mode13 )
 
 const char * Window_vector::remove_duplicate_lines( const bool back )
   {
-  Buffer & buffer = data[curwin_].buffer();
+  Window & w = curwin();
+  Buffer & buffer = w.buffer();
   if( no_block() || no_block_in_this_file( buffer ) || rectangular_block() ||
       read_only( buffer ) ) return 0;
 
   bool change = false;
-  const int first_line = Block::begin().line + ( Block::begin().col > 0 );
-  int last_line = std::min( Block::end().line, buffer.lines() ) - 1;
+  const long first_line = Block::begin().line + ( Block::begin().col > 0 );
+  long last_line = std::min( Block::end().line, buffer.lines() ) - 1;
   if( back )
     {
-    for( int line1 = last_line; line1 > first_line; --line1 )
-      for( int line2 = line1 - 1; line2 >= first_line; --line2 )
+    for( long line1 = last_line; line1 > first_line; --line1 )
+      for( long line2 = line1 - 1; line2 >= first_line; --line2 )
         if( buffer.compare_lines( line1, line2 ) )
           {
           if( change ) buffer.force_append(); else change = true;
@@ -1050,8 +1037,8 @@ const char * Window_vector::remove_duplicate_lines( const bool back )
     }
   else
     {
-    for( int line1 = first_line; line1 < last_line; ++line1 )
-      for( int line2 = last_line; line2 > line1; --line2 )
+    for( long line1 = first_line; line1 < last_line; ++line1 )
+      for( long line2 = last_line; line2 > line1; --line2 )
         if( buffer.compare_lines( line1, line2 ) )
           {
           if( change ) buffer.force_append(); else change = true;
@@ -1064,8 +1051,8 @@ const char * Window_vector::remove_duplicate_lines( const bool back )
   buffer.reset_appendable();
   if( Block::valid() )
     {
-    if( back ) data[curwin_].update_points( Block::end(), true, true );
-    else data[curwin_].update_points( Block::begin(), true, true );
+    if( back ) w.update_points( Block::end(), true, true );
+    else w.update_points( Block::begin(), true, true );
     }
   if( RC::editor_options().auto_unmark ) Block::reset();
   Screen::repaint( &buffer );
@@ -1105,26 +1092,27 @@ const char * Window_vector::copyright_update()
   bool skipped = false;
   for( int i = Bufhandle_vector::handles(); i > 0; next(), --i )
     {
-    Window & w = data[curwin_];
-    if( w.buffer().options.read_only ) { skipped = true; continue; }
-    Point p = w.buffer().bof();
+    Window & w = curwin();
+    Buffer & buffer = w.buffer();
+    if( buffer.options.read_only ) { skipped = true; continue; }
+    Point p = buffer.bof();
     std::vector< std::string > regex_pieces;
     while( true )
       {
       Point pn = p;			// begin of notice
-      if( Regex::find( w.buffer(), pn, p, search_string, regex_pieces ) != 0 )
+      if( Regex::find( buffer, pn, p, search_string, regex_pieces ) != 0 )
         break;				// no more copyrights found
       Point py = pn;			// begin of range of years
       Point pt;
-      if( Regex::find( w.buffer(), py, pt, search_string2, regex_pieces ) != 0 ||
+      if( Regex::find( buffer, py, pt, search_string2, regex_pieces ) != 0 ||
           py <= pn || pt >= p )
         continue;			// not a valid copyright notice
       found = true;
-      const Point p0 = w.buffer().bol( pn );	// bol of notice
-      const Point ph2 = w.buffer().eol( p );	// end of copyright holder
-      w.buffer().pprev( p );			// begin of copyright holder
-      Basic_buffer tmp( w.buffer(), p0, py );	// "<prefix> Copyright <text>"
-      if( insert_new_year( w.buffer(), p0, pn, py, p, ph2, new_year, tmp ) )
+      const Point p0 = buffer.bol( pn );	// bol of notice
+      const Point ph2 = buffer.eol( p );	// end of copyright holder
+      buffer.pprev( p );			// begin of copyright holder
+      Basic_buffer tmp( buffer, p0, py );	// "<prefix> Copyright <text>"
+      if( insert_new_year( buffer, p0, pn, py, p, ph2, new_year, tmp ) )
         {
         outdated = true;
         p = ph2;
@@ -1139,9 +1127,9 @@ const char * Window_vector::copyright_update()
           }
         if( !ask || key == 'y' || key == 'Y' )
           {
-          w.buffer().replace( p0, p, tmp, tmp.bof(), tmp.eof() );
+          buffer.replace( p0, p, tmp, tmp.bof(), tmp.eof() );
           w.update_points( p, true, true );
-          Screen::repaint( &w.buffer() );
+          Screen::repaint( &buffer );
           modified = true;
           }
         }
@@ -1166,8 +1154,8 @@ const char * Window_vector::copyright_update()
 
 const char * Window_vector::search_word( const int abort_key )
   {
-  const Buffer & buffer = data[curwin_].buffer();
-  Point p1 = data[curwin_].pointer();
+  const Buffer & buffer = curwin().buffer();
+  Point p1 = curwin().pointer();
   if( ISO_8859::isalnum_( buffer[p1] ) || buffer.piseow( p1 ) )
     {
     Point p2 = p1;
@@ -1270,13 +1258,13 @@ const char * Window_vector::search( const int abort_key, const bool again,
     if( feedback )
       { feedback = false;
         Screen::show_feedback( ask ? "searching..." : "replacing..." ); }
-    Window & w = data[curwin_];
+    Window & w = curwin();
     std::vector< std::string > regex_pieces;
     Point p1 = p, p2 = p;
-    { const int tmp = Regex::find( w.buffer(), p1, p2, search_string,
+    { const int ret = Regex::find( w.buffer(), p1, p2, search_string,
                                    regex_pieces, icase, backward );
-    if( tmp == 2 ) { msg = "Search error: check syntax"; break; }
-    found = ( tmp == 0 ); }
+    if( ret == 2 ) { msg = "Search error: check syntax"; break; }
+    found = ( ret == 0 ); }
     empty_replace = ( found && ( p1 == p2 ) );
     if( found && block &&
         ( p1 < Block::begin() || p1 >= Block::end() || p2 > Block::end() ) )
